@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,42 +13,34 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the BasicEditorFactory class, which allows creating editor
     factories that use the same class for creating all editor styles.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from traits.api import Any
 
 from .editor_factory import EditorFactory
 
-#-------------------------------------------------------------------------
-#  'BasicEditorFactory' base class:
-#-------------------------------------------------------------------------
-
 
 class BasicEditorFactory(EditorFactory):
     """ Base class for editor factories that use the same class for creating
         all editor styles.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     # Editor class to be instantiated
-    klass = Any
+    klass = Any()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Property getters.
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _get_simple_editor_class(self):
         """ Returns the editor class to use for "simple" style views.
@@ -78,11 +70,7 @@ class BasicEditorFactory(EditorFactory):
         """
         return self.klass
 
-    #-------------------------------------------------------------------------
-    #  Allow an instance to be called:
-    #-------------------------------------------------------------------------
-
     def __call__(self, *args, **traits):
-        return self.set(**traits)
-
-## EOF ########################################################################
+        new = self.clone_traits()
+        new.trait_set(**traits)
+        return new
