@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,51 +13,48 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the button editor factory for all traits toolkit backends.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from pyface.ui_traits import Image
-from traits.api import Str, Range, Enum, Property, Trait
+from traits.api import Str, Range, Enum, Property, Either
 
 from ..editor_factory import EditorFactory
 from ..ui_traits import AView
 from ..view import View
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ToolkitEditorFactory(EditorFactory):
     """ Editor factory for buttons.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     # Value to set when the button is clicked
-    value = Property
+    value = Property()
 
     # Optional label for the button
-    label = Str
+    label = Str()
 
     # The name of the external object trait that the button label is synced to
-    label_value = Str
+    label_value = Str()
 
     # The name of the trait on the object that contains the list of possible
     # values.  If this is set, then the value, label, and label_value traits
     # are ignored; instead, they will be set from this list.  When this button
     # is clicked, the value set will be the one selected from the drop-down.
-    values_trait = Trait(None, None, Str)
+    values_trait = Either(None, Str)
 
     # (Optional) Image to display on the button
     image = Image
@@ -69,23 +66,19 @@ class ToolkitEditorFactory(EditorFactory):
     height_padding = Range(0, 31, 5)
 
     # Presentation style
-    style = Enum('button', 'radio', 'toolbar', 'checkbox')
+    style = Enum("button", "radio", "toolbar", "checkbox")
 
     # Orientation of the text relative to the image
-    orientation = Enum('vertical', 'horizontal')
+    orientation = Enum("vertical", "horizontal")
 
     # The optional view to display when the button is clicked:
     view = AView
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Traits view definition:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    traits_view = View(['label', 'value', '|[]'])
-
-    #-------------------------------------------------------------------------
-    #  Implementation of the 'value' property:
-    #-------------------------------------------------------------------------
+    traits_view = View(["label", "value", "|[]"])
 
     def _get_value(self):
         return self._value
@@ -101,10 +94,6 @@ class ToolkitEditorFactory(EditorFactory):
                 except:
                     pass
 
-    #-------------------------------------------------------------------------
-    #  Initializes the object:
-    #-------------------------------------------------------------------------
-
     def __init__(self, **traits):
         self._value = 0
         super(ToolkitEditorFactory, self).__init__(**traits)
@@ -112,5 +101,3 @@ class ToolkitEditorFactory(EditorFactory):
 
 # Define the ButtonEditor class
 ButtonEditor = ToolkitEditorFactory
-
-### EOF ---------------------------------------------------------------------
