@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,16 +13,12 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Defines a text editor which displays a text field and maintains a history
     of previously entered values.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from traits.api import Int, Bool
@@ -36,22 +32,22 @@ from ..toolkit import toolkit_object
 
 
 def history_editor(*args, **traits):
-    return toolkit_object('history_editor:_HistoryEditor')(*args, **traits)
+    return toolkit_object("history_editor:_HistoryEditor")(*args, **traits)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Create the editor factory object:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ToolkitEditorFactory(BasicEditorFactory):
 
-    # The number of entries in the history:
+    #: The number of entries in the history:
     entries = Int(10)
 
-    # Should each keystroke update the value (or only the enter key, tab,
-    # etc.)?
+    #: Should each keystroke update the value (or only the enter key, tab,
+    #: etc.)?
     auto_set = Bool(False)
 
 
 HistoryEditor = ToolkitEditorFactory(klass=history_editor)
-# EOF #########################################################################
