@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,15 +13,11 @@
 #  Author: David C. Morrill
 #  Date:   07/26/2006
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Defines a completely empty editor, intended to be used as a spacer.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from ..basic_editor_factory import BasicEditorFactory
@@ -32,11 +28,10 @@ from ..toolkit import toolkit_object
 
 
 def null_editor(*args, **traits):
-    return toolkit_object('null_editor:NullEditor')(*args, **traits)
+    return toolkit_object("null_editor:NullEditor")(*args, **traits)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Create the editor factory object:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 NullEditor = BasicEditorFactory(klass=null_editor)
-
-### EOF ---------------------------------------------------------------------
