@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -12,14 +12,10 @@
 #
 #  Author: David C. Morrill
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 """ Defines the tree editor factory for all traits user interface toolkits.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from traits.api import Any, Dict, Bool, Tuple, Int, List, Instance, Str, Enum
@@ -30,54 +26,65 @@ from ..dock_window_theme import DockWindowTheme
 from ..editor_factory import EditorFactory
 from ..helper import Orientation
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Trait definitions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Size of each tree node icon
 IconSize = Tuple((16, 16), Int, Int)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  The core tree node menu actions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
-NewAction = 'NewAction'
-CopyAction = Action(name='Copy',
-                    action='editor._menu_copy_node',
-                    enabled_when='editor._is_copyable(object)')
-CutAction = Action(name='Cut',
-                   action='editor._menu_cut_node',
-                   enabled_when='editor._is_cutable(object)')
-PasteAction = Action(name='Paste',
-                     action='editor._menu_paste_node',
-                     enabled_when='editor._is_pasteable(object)')
-DeleteAction = Action(name='Delete',
-                      action='editor._menu_delete_node',
-                      enabled_when='editor._is_deletable(object)')
-RenameAction = Action(name='Rename',
-                      action='editor._menu_rename_node',
-                      enabled_when='editor._is_renameable(object)')
+NewAction = "NewAction"
+CopyAction = Action(
+    name="Copy",
+    action="editor._menu_copy_node",
+    enabled_when="editor._is_copyable(object)",
+)
+CutAction = Action(
+    name="Cut",
+    action="editor._menu_cut_node",
+    enabled_when="editor._is_cutable(object)",
+)
+PasteAction = Action(
+    name="Paste",
+    action="editor._menu_paste_node",
+    enabled_when="editor._is_pasteable(object)",
+)
+DeleteAction = Action(
+    name="Delete",
+    action="editor._menu_delete_node",
+    enabled_when="editor._is_deletable(object)",
+)
+RenameAction = Action(
+    name="Rename",
+    action="editor._menu_rename_node",
+    enabled_when="editor._is_renameable(object)",
+)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ToolkitEditorFactory(EditorFactory):
     """ Editor factory for tree editors.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     #: Supported TreeNode objects
     nodes = List(TreeNode)
 
     #: Mapping from TreeNode tuples to MultiTreeNodes
-    multi_nodes = Dict
+    multi_nodes = Dict()
 
     #: The column header labels if any.
     column_headers = List(Str)
@@ -86,7 +93,7 @@ class ToolkitEditorFactory(EditorFactory):
     editable = Bool(True)
 
     #: Selection mode.
-    selection_mode = Enum('single', 'extended')
+    selection_mode = Enum("single", "extended")
 
     #: Is the editor shared across trees?
     shared_editor = Bool(False)
@@ -109,48 +116,48 @@ class ToolkitEditorFactory(EditorFactory):
 
     #: Number of tree levels (down from the root) that should be automatically
     #: opened
-    auto_open = Int
+    auto_open = Int()
 
     #: Size of the tree node icons
     icon_size = IconSize
 
     #: Called when a node is selected
-    on_select = Any
+    on_select = Any()
 
     #: Called when a node is clicked
-    on_click = Any
+    on_click = Any()
 
     #: Called when a node is double-clicked
-    on_dclick = Any
+    on_dclick = Any()
 
     #: Called when a node is activated
-    on_activated = Any
+    on_activated = Any()
 
     #: Call when the mouse hovers over a node
-    on_hover = Any
+    on_hover = Any()
 
     #: The optional extended trait name of the trait to synchronize with the
     #: editor's current selection:
-    selected = Str
+    selected = Str()
 
     #: The optional extended trait name of the trait that should be assigned
     #: a node object when a tree node is activated, by double-clicking or
     #: pressing the Enter key when a node has focus (Note: if you want to
     #: receive repeated activated events on the same node, make sure the trait
     #: is defined as an Event):
-    activated = Str
+    activated = Str()
 
     #: The optional extended trait name of the trait that should be assigned
     #: a node object when a tree node is clicked on (Note: If you want to
     #: receive repeated clicks on the same node, make sure the trait is defined
     #: as an Event):
-    click = Str
+    click = Str()
 
     #: The optional extended trait name of the trait that should be assigned
     #: a node object when a tree node is double-clicked on (Note: if you want to
     #: receive repeated double-clicks on the same node, make sure the trait is
     #: defined as an Event):
-    dclick = Str
+    dclick = Str()
 
     #: The optional extended trait name of the trait event that is fired
     #: whenever the application wishes to veto a tree action in progress (e.g.
@@ -159,19 +166,19 @@ class ToolkitEditorFactory(EditorFactory):
     #: wish to veto the open or close operation). Be sure to fire the veto event
     #: in the event handler triggered by the operation (e.g. the 'dclick' event
     #: handler.
-    veto = Str
+    veto = Str()
 
     #: The optional extended trait name of the trait event that is fired when the
     #: application wishes the currently visible portion of the tree widget to
     #: repaint itself.
-    refresh = Str
+    refresh = Str()
 
     #: Mode for lines connecting tree nodes
     #:
     #: * 'appearance': Show lines only when they look good.
     #: * 'on': Always show lines.
     #: * 'off': Don't show lines.
-    lines_mode = Enum('appearance', 'on', 'off')
+    lines_mode = Enum("appearance", "on", "off")
 
     # FIXME: Document as unimplemented or wx specific.
     #: Whether to alternate row colors or not.
@@ -187,5 +194,6 @@ class ToolkitEditorFactory(EditorFactory):
     #: This works only in the qt backend and if there is only one column in tree
     word_wrap = Bool(False)
 
+
 #: Define the TreeEditor class.
 TreeEditor = ToolkitEditorFactory
