@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -12,19 +12,24 @@
 #
 #  Author: David C. Morrill
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 """ Defines the tuple editor factory for all traits user interface toolkits.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from traits.trait_base import SequenceTypes
 
-from traits.api import Bool, HasTraits, List, Tuple, Unicode, Int, Any, TraitType
+from traits.api import (
+    BaseTuple,
+    Bool,
+    HasTraits,
+    List,
+    Str,
+    Int,
+    Any,
+    TraitType,
+)
 
 # CIRCULAR IMPORT FIXME: Importing from the source rather than traits.ui.api
 # to avoid circular imports, as this EditorFactory will be part of
@@ -39,44 +44,41 @@ from ..editor_factory import EditorFactory
 
 from ..editor import Editor
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ToolkitEditorFactory(EditorFactory):
     """ Editor factory for tuple editors.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Trait definitions for each tuple field
-    types = Any
+    #: Trait definitions for each tuple field
+    types = Any()
 
-    # Labels for each of the tuple fields
-    labels = List(Unicode)
+    #: Labels for each of the tuple fields
+    labels = List(Str)
 
-    # Editors for each of the tuple fields:
+    #: Editors for each of the tuple fields:
     editors = List(EditorFactory)
 
-    # Number of tuple fields or rows
+    #: Number of tuple fields or rows
     cols = Int(1)
 
-    # Is user input set on every keystroke? This is applied to every field
-    # of the tuple, provided the field does not already have an 'auto_set'
-    # metadata or an editor defined.
+    #: Is user input set on every keystroke? This is applied to every field
+    #: of the tuple, provided the field does not already have an 'auto_set'
+    #: metadata or an editor defined.
     auto_set = Bool(True)
 
-    # Is user input set when the Enter key is pressed? This is applied to
-    # every field of the tuple, provided the field does not already have an
-    # 'enter_set' metadata or an editor defined.
+    #: Is user input set when the Enter key is pressed? This is applied to
+    #: every field of the tuple, provided the field does not already have an
+    #: 'enter_set' metadata or an editor defined.
     enter_set = Bool(False)
 
-#-------------------------------------------------------------------------
-#  'SimpleEditor' class:
-#-------------------------------------------------------------------------
-
 
 class SimpleEditor(Editor):
     """ Simple style of editor for tuples.
@@ -84,66 +86,48 @@ class SimpleEditor(Editor):
     The editor displays an editor for each of the fields in the tuple, based on
     the type of each field.
     """
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
         self._ts = ts = TupleStructure(self)
-        self._ui = ui = ts.view.ui(ts, parent, kind='subpanel').set(
-            parent=self.ui)
+        self._ui = ui = ts.view.ui(ts, parent, kind="subpanel").trait_set(
+            parent=self.ui
+        )
         self.control = ui.control
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
             editor.
         """
         ts = self._ts
         for i, value in enumerate(self.value):
-            setattr(ts, 'f%d' % i, value)
-
-    #-------------------------------------------------------------------------
-    #  Returns the editor's control for indicating error status:
-    #-------------------------------------------------------------------------
+            setattr(ts, "f%d" % i, value)
 
     def get_error_control(self):
         """ Returns the editor's control for indicating error status.
         """
         return self._ui.get_error_controls()
 
-#-------------------------------------------------------------------------
-#  'TupleStructure' class:
-#-------------------------------------------------------------------------
-
 
 class TupleStructure(HasTraits):
     """ Creates a view containing items for each field in a tuple.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Editor this structure is linked to
-    editor = Any
+    #: Editor this structure is linked to
+    editor = Any()
 
-    # The constructed View for the tuple
-    view = Any
+    #: The constructed View for the tuple
+    view = Any()
 
-    # Number of tuple fields
-    fields = Int
-
-    #-------------------------------------------------------------------------
-    #  Initializes the object:
-    #-------------------------------------------------------------------------
+    #: Number of tuple fields
+    fields = Int()
 
     def __init__(self, editor):
         """ Initializes the object.
@@ -169,7 +153,7 @@ class TupleStructure(HasTraits):
 
         if types is None:
             type = editor.value_trait.handler
-            if isinstance(type, Tuple):
+            if isinstance(type, BaseTuple):
                 types = type.types
 
         if not isinstance(types, SequenceTypes):
@@ -192,7 +176,7 @@ class TupleStructure(HasTraits):
             if enter_set is None:
                 enter_set = editor.factory.enter_set
 
-            label = ''
+            label = ""
             if i < len_labels:
                 label = labels[i]
 
@@ -200,26 +184,28 @@ class TupleStructure(HasTraits):
             if i < len_editors:
                 field_editor = editors[i]
 
-            name = 'f%d' % i
-            self.add_trait(name, type(value, event='field',
-                                      auto_set=auto_set,
-                                      enter_set=enter_set))
+            name = "f%d" % i
+            self.add_trait(
+                name,
+                type(
+                    value,
+                    event="field",
+                    auto_set=auto_set,
+                    enter_set=enter_set,
+                ),
+            )
             item = Item(name=name, label=label, editor=field_editor)
             if cols <= 1:
                 content.append(item)
             else:
                 if (i % cols) == 0:
-                    group = Group(orientation='horizontal')
+                    group = Group(orientation="horizontal")
                     content.append(group)
 
                 group.content.append(item)
 
         self.view = View(Group(show_labels=(len_labels != 0), *content))
 
-    #-------------------------------------------------------------------------
-    #  Updates the underlying tuple when any field changes value:
-    #-------------------------------------------------------------------------
-
     def _field_changed(self, name, old, new):
         """ Updates the underlying tuple when any field changes value.
         """
@@ -227,10 +213,9 @@ class TupleStructure(HasTraits):
         value = self.editor.value
         if new != value[index]:
             self.editor.value = tuple(
-                [getattr(self, 'f%d' % i) for i in range(self.fields)])
+                [getattr(self, "f%d" % i) for i in range(self.fields)]
+            )
 
 
 # Define the TupleEditor class.
 TupleEditor = ToolkitEditorFactory
-
-### EOF #######################################################################
