@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,39 +8,35 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the PyQt implementation of the editor used to wrap a non-Traits
 based custom control.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from pyface.qt import QtGui
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.custom_editor file.
-from traitsui.editors.custom_editor \
-    import ToolkitEditorFactory
+from traitsui.editors.custom_editor import ToolkitEditorFactory
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'CustomEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class CustomEditor(Editor):
     """ Wrapper for a custom editor control
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -51,14 +47,15 @@ class CustomEditor(Editor):
             self.control = factory(*((parent, self) + self.factory.args))
         if self.control is None:
             self.control = QtGui.QLabel(
-                'An error occurred creating a custom editor.\n'
-                'Please contact the developer.')
+                "An error occurred creating a custom editor.\n"
+                "Please contact the developer."
+            )
             self.control.setStyleSheet("background-color: red; color: white")
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
