@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,15 +8,12 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines a drop target editor for the PyQt user interface toolkit. A drop
 target editor handles drag and drop operations as a drop target.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from pyface.qt import QtGui, QtCore
 
@@ -29,24 +26,15 @@ from .text_editor import SimpleEditor as Editor
 from .constants import DropColor
 from .clipboard import PyMimeData, clipboard
 
-#-------------------------------------------------------------------------
-#  'SimpleEditor' class:
-#-------------------------------------------------------------------------
-
 
 class SimpleEditor(Editor):
     """ Simple style of drop editor, which displays a read-only text field that
     contains the string representation of the object trait's value.
     """
 
-    # Background color when it is OK to drop objects.
+    #: Background color when it is OK to drop objects.
     ok_color = DropColor
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -68,21 +56,13 @@ class SimpleEditor(Editor):
 
         self.control._qt4_editor = self
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified object trait value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, value):
         """ Returns the text representation of a specified object trait value.
         """
         if value is None:
-            return ''
+            return ""
         return str(value)
 
-    #-------------------------------------------------------------------------
-    #  Handles an error that occurs while setting the object's trait value:
-    #-------------------------------------------------------------------------
-
     def error(self, excp):
         """ Handles an error that occurs while setting the object's trait value.
         """
@@ -90,7 +70,6 @@ class SimpleEditor(Editor):
 
 
 class _DropEventFilter(QtCore.QObject):
-
     def eventFilter(self, source, event):
         typ = event.type()
         if typ == QtCore.QEvent.Drop:
@@ -99,10 +78,6 @@ class _DropEventFilter(QtCore.QObject):
             self.dragEnterEvent(event)
         return super(_DropEventFilter, self).eventFilter(source, event)
 
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dropped on the control:
-    #-------------------------------------------------------------------------
-
     def dropEvent(self, e):
         """ Handles a Python object being dropped on the tree.
         """
@@ -111,18 +86,18 @@ class _DropEventFilter(QtCore.QObject):
         klass = editor.factory.klass
 
         if editor.factory.binding:
-            value = getattr(clipboard, 'node', None)
+            value = getattr(clipboard, "node", None)
         else:
             value = e.mimeData().instance()
 
         if (klass is None) or isinstance(value, klass):
             editor._no_update = True
             try:
-                if hasattr(value, 'drop_editor_value'):
+                if hasattr(value, "drop_editor_value"):
                     editor.value = value.drop_editor_value()
                 else:
                     editor.value = value
-                if hasattr(value, 'drop_editor_update'):
+                if hasattr(value, "drop_editor_update"):
                     value.drop_editor_update(self)
                 else:
                     self.setText(editor.str_value)
@@ -131,17 +106,13 @@ class _DropEventFilter(QtCore.QObject):
 
             e.acceptProposedAction()
 
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dragged over the control:
-    #-------------------------------------------------------------------------
-
     def dragEnterEvent(self, e):
         """ Handles a Python object being dragged over the tree.
         """
         editor = self.parent()._qt4_editor
 
         if editor.factory.binding:
-            data = getattr(clipboard, 'node', None)
+            data = getattr(clipboard, "node", None)
         else:
             md = e.mimeData()
 
@@ -151,8 +122,9 @@ class _DropEventFilter(QtCore.QObject):
             data = md.instance()
 
         try:
-            editor.object.base_trait(editor.name).validate(editor.object,
-                                                           editor.name, data)
+            editor.object.base_trait(editor.name).validate(
+                editor.object, editor.name, data
+            )
             e.acceptProposedAction()
         except:
             pass
