@@ -1,20 +1,22 @@
 from pyface.qt import QtGui, QtCore
 
-from traits.api import Float, Any, Str, Trait
+from traits.api import Float, Any, Str, Either
+
 from traitsui.editors.api import RangeEditor
 from traitsui.qt4.editor import Editor
 from traitsui.qt4.extra.range_slider import RangeSlider
 
 
+
 class _BoundsEditor(Editor):
 
-    evaluate = Any
+    evaluate = Any()
 
-    min = Any
-    max = Any
-    low = Any
-    high = Any
-    format = Str
+    min = Any()
+    max = Any()
+    low = Any()
+    high = Any()
+    format = Str()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -33,10 +35,10 @@ class _BoundsEditor(Editor):
         self.format = factory.format
 
         self.evaluate = factory.evaluate
-        self.sync_value(factory.evaluate_name, 'evaluate', 'from')
+        self.sync_value(factory.evaluate_name, "evaluate", "from")
 
-        self.sync_value(factory.low_name, 'low', 'both')
-        self.sync_value(factory.high_name, 'high', 'both')
+        self.sync_value(factory.low_name, "low", "both")
+        self.sync_value(factory.high_name, "high", "both")
 
         self.control = QtGui.QWidget()
         panel = QtGui.QHBoxLayout(self.control)
@@ -147,7 +149,9 @@ class _BoundsEditor(Editor):
             self.min = self.low
 
     def _step_size(self):
-        slider_delta = self.control.slider.maximum() - self.control.slider.minimum()
+        slider_delta = (
+            self.control.slider.maximum() - self.control.slider.minimum()
+        )
         range_delta = self.max - self.min
 
         return float(range_delta) / slider_delta
@@ -158,7 +162,10 @@ class _BoundsEditor(Editor):
 
     def _convert_to_slider(self, value):
         self._check_max_and_min()
-        return self.control.slider.minimum() + (value - self.min) / self._step_size()
+        return (
+            self.control.slider.minimum()
+            + (value - self.min) / self._step_size()
+        )
 
     def _low_changed(self, low):
         if self.control is None:
@@ -179,8 +186,8 @@ class _BoundsEditor(Editor):
 
 class BoundsEditor(RangeEditor):
 
-    min = Trait(None, Float)
-    max = Trait(None, Float)
+    min = Either(None, Float)
+    max = Either(None, Float)
 
     def _get_simple_editor_class(self):
         return _BoundsEditor
