@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,15 +13,11 @@
 #  Author: Evan Patterson
 #  Date:   07/21/2009
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Traits UI 'display only' image editor.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from pyface.qt.QtGui import QFrame, QPainter, QPalette
@@ -36,9 +32,9 @@ from traitsui.editors.image_editor import ImageEditor
 
 from .editor import Editor
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'QImageView' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # backported and modified from Enaml ImageView
 
@@ -68,9 +64,9 @@ class QImageView(QFrame):
 
         self.setBackgroundRole(QPalette.Window)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # Private API
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def paintEvent(self, event):
         """ A custom paint event handler which draws the image according
         to the current size constraints.
@@ -92,8 +88,8 @@ class QImageView(QFrame):
         if not self._scaled_contents:
             # If the image isn't scaled, it is centered if possible.
             # Otherwise, it's painted at the origin and clipped.
-            paint_x = max(0, int(width / 2. - pm_width / 2.))
-            paint_y = max(0, int(height / 2. - pm_height / 2.))
+            paint_x = max(0, int(width / 2.0 - pm_width / 2.0))
+            paint_y = max(0, int(height / 2.0 - pm_height / 2.0))
             paint_width = pm_width
             paint_height = pm_height
         else:
@@ -123,17 +119,17 @@ class QImageView(QFrame):
                     paint_width = min(pm_width, width)
             # In all cases of scaling, we know that the scaled image is
             # no larger than the paint area, and can thus be centered.
-            paint_x = int(width / 2. - paint_width / 2.)
-            paint_y = int(height / 2. - paint_height / 2.)
+            paint_x = int(width / 2.0 - paint_width / 2.0)
+            paint_y = int(height / 2.0 - paint_height / 2.0)
 
         # Finally, draw the pixmap into the calculated rect.
         painter = QPainter(self)
         painter.setRenderHint(QPainter.SmoothPixmapTransform)
         painter.drawPixmap(paint_x, paint_y, paint_width, paint_height, pixmap)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # Public API
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def sizeHint(self):
         """ Returns a appropriate size hint for the image based on the
         underlying QPixmap.
@@ -150,7 +146,11 @@ class QImageView(QFrame):
 
         """
         pixmap = self._pixmap
-        if pixmap is not None and not self._allow_clipping and not self._scaled_contents:
+        if (
+            pixmap is not None
+            and not self._allow_clipping
+            and not self._scaled_contents
+        ):
             return pixmap.size()
         return super(QImageView, self).sizeHint()
 
@@ -257,19 +257,15 @@ class QImageView(QFrame):
         self.update()
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  '_ImageEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class _ImageEditor(Editor):
     """ Traits UI 'display only' image editor.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -287,10 +283,6 @@ class _ImageEditor(Editor):
 
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
