@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,21 +13,28 @@
 #  Author: Evan Patterson
 #  Date:   08/05/2009
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Traits UI editor for editing lists of strings.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_qt5
 import collections
 
 from pyface.image_resource import ImageResource
-from traits.api import Any, Bool, Event, Int, Instance, List, \
-    Property, Str, TraitListEvent, NO_COMPARE
+from traits.api import (
+    Any,
+    Bool,
+    Event,
+    Int,
+    Instance,
+    List,
+    Property,
+    Str,
+    TraitListEvent,
+    NO_COMPARE,
+)
 from traitsui.list_str_adapter import ListStrAdapter
 
 from .editor import Editor
@@ -35,73 +42,66 @@ from .list_str_model import ListStrModel
 from traitsui.menu import Menu
 
 
-is_qt5 = (QtCore.__version_info__[0] >= 5)
-
-#-------------------------------------------------------------------------
-#  '_ListStrEditor' class:
-#-------------------------------------------------------------------------
-
-
 class _ListStrEditor(Editor):
     """ Traits UI editor for editing lists of strings.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     # The list view control associated with the editor:
-    list_view = Any
+    list_view = Any()
 
-    # The list model associated the editor:
+    #: The list model associated the editor:
     model = Instance(ListStrModel)
 
-    # The title of the editor:
-    title = Str
+    #: The title of the editor:
+    title = Str()
 
-    # The current set of selected items (which one is used depends upon the
-    # initial state of the editor factory 'multi_select' trait):
-    selected = Any
-    multi_selected = List
+    #: The current set of selected items (which one is used depends upon the
+    #: initial state of the editor factory 'multi_select' trait):
+    selected = Any()
+    multi_selected = List()
 
-    # The current set of selected item indices (which one is used depends upon
-    # the initial state of the editor factory 'multi_select' trait):
+    #: The current set of selected item indices (which one is used depends upon
+    #: the initial state of the editor factory 'multi_select' trait):
     selected_index = Int(-1)
     multi_selected_indices = List(Int)
 
-    # The most recently actived item and its index.
-    # Always trigger change notification.
+    #: The most recently actived item and its index.
+    #: Always trigger change notification.
     activated = Any(comparison_mode=NO_COMPARE)
     activated_index = Int(comparison_mode=NO_COMPARE)
 
-    # The most recently right_clicked item and its index:
-    right_clicked = Event
-    right_clicked_index = Event
+    #: The most recently right_clicked item and its index:
+    right_clicked = Event()
+    right_clicked_index = Event()
 
-    # Is the list editor scrollable? This value overrides the default.
+    #: Is the list editor scrollable? This value overrides the default.
     scrollable = True
 
-    # Should the selected item be edited after rebuilding the editor list:
+    #: Should the selected item be edited after rebuilding the editor list:
     edit = Bool(False)
 
-    # The adapter from list items to editor values:
+    #: The adapter from list items to editor values:
     adapter = Instance(ListStrAdapter)
 
-    # Dictionary mapping image names to QIcons
+    #: Dictionary mapping image names to QIcons
     images = Any({})
 
-    # Dictionary mapping ImageResource objects to QIcons
+    #: Dictionary mapping ImageResource objects to QIcons
     image_resources = Any({})
 
-    # The current number of item currently in the list:
-    item_count = Property
+    #: The current number of item currently in the list:
+    item_count = Property()
 
-    # The current search string:
-    search = Str
+    #: The current search string:
+    search = Str()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Editor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -111,7 +111,7 @@ class _ListStrEditor(Editor):
 
         # Set up the adapter to use:
         self.adapter = factory.adapter
-        self.sync_value(factory.adapter_name, 'adapter', 'from')
+        self.sync_value(factory.adapter_name, "adapter", "from")
 
         # Create the list model and accompanying controls:
         self.model = ListStrModel(editor=self)
@@ -146,32 +146,37 @@ class _ListStrEditor(Editor):
 
         # Initialize the editor title:
         self.title = factory.title
-        self.sync_value(factory.title_name, 'title', 'from')
+        self.sync_value(factory.title_name, "title", "from")
 
         # Set up the selection listener
         if factory.multi_select:
-            self.sync_value(factory.selected, 'multi_selected', 'both',
-                            is_list=True)
-            self.sync_value(factory.selected_index, 'multi_selected_indices',
-                            'both', is_list=True)
+            self.sync_value(
+                factory.selected, "multi_selected", "both", is_list=True
+            )
+            self.sync_value(
+                factory.selected_index,
+                "multi_selected_indices",
+                "both",
+                is_list=True,
+            )
         else:
-            self.sync_value(factory.selected, 'selected', 'both')
-            self.sync_value(factory.selected_index, 'selected_index', 'both')
+            self.sync_value(factory.selected, "selected", "both")
+            self.sync_value(factory.selected_index, "selected_index", "both")
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.activated, 'activated', 'to')
-        self.sync_value(factory.activated_index, 'activated_index', 'to')
+        self.sync_value(factory.activated, "activated", "to")
+        self.sync_value(factory.activated_index, "activated_index", "to")
 
-        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
+        self.sync_value(factory.right_clicked, "right_clicked", "to")
         self.sync_value(
-            factory.right_clicked_index,
-            'right_clicked_index',
-            'to')
+            factory.right_clicked_index, "right_clicked_index", "to"
+        )
 
         # Make sure we listen for 'items' changes as well as complete list
         # replacements:
         self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + '_items', dispatch='ui')
+            self.update_editor, self.extended_name + "_items", dispatch="ui"
+        )
 
         # Create the mapping from user supplied images to QIcons:
         for image_resource in factory.images:
@@ -179,7 +184,8 @@ class _ListStrEditor(Editor):
 
         # Refresh the editor whenever the adapter changes:
         self.on_trait_change(
-            self.refresh_editor, 'adapter.+update', dispatch='ui')
+            self.refresh_editor, "adapter.+update", dispatch="ui"
+        )
 
         # Set the list control's tooltip:
         self.set_tooltip()
@@ -188,10 +194,12 @@ class _ListStrEditor(Editor):
         """ Disposes of the contents of an editor.
         """
         self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + '_items', remove=True)
+            self.update_editor, self.extended_name + "_items", remove=True
+        )
 
         self.on_trait_change(
-            self.refresh_editor, 'adapter.+update', remove=True)
+            self.refresh_editor, "adapter.+update", remove=True
+        )
 
         super(Editor, self).dispose()
 
@@ -208,9 +216,9 @@ class _ListStrEditor(Editor):
             else:
                 self._selected_changed(self.selected)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  ListStrEditor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def refresh_editor(self):
         """ Requests that the underlying list widget to redraw itself.
@@ -233,7 +241,7 @@ class _ListStrEditor(Editor):
         old = self._no_notify
         self._no_notify = True
         try:
-            for name, value in list(keywords.items()):
+            for name, value in keywords.items():
                 setattr(self, name, value)
         finally:
             self._no_notify = old
@@ -254,12 +262,13 @@ class _ListStrEditor(Editor):
         """ Returns whether or not the index is the special 'auto add' item at
             the end of the list.
         """
-        return (self.factory.auto_add and
-                (index >= self.adapter.len(self.object, self.name)))
+        return self.factory.auto_add and (
+            index >= self.adapter.len(self.object, self.name)
+        )
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Private interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
         """ Adds a new image to the image map.
@@ -271,12 +280,12 @@ class _ListStrEditor(Editor):
 
         return image
 
-    #-- Property Implementations ---------------------------------------------
+    # -- Property Implementations ---------------------------------------------
 
     def _get_item_count(self):
-        return (self.model.rowCount(None) - self.factory.auto_add)
+        return self.model.rowCount(None) - self.factory.auto_add
 
-    #-- Trait Event Handlers -------------------------------------------------
+    # -- Trait Event Handlers -------------------------------------------------
 
     def _selected_changed(self, selected):
         """ Handles the editor's 'selected' trait being changed.
@@ -333,8 +342,10 @@ class _ListStrEditor(Editor):
             smodel = self.list_view.selectionModel()
             smodel.clearSelection()
             for selected_index in selected_indices:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Select)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Select,
+                )
             if selected_indices:
                 self.list_view.scrollTo(self.model.index(selected_indices[-1]))
 
@@ -344,13 +355,17 @@ class _ListStrEditor(Editor):
         if not self._no_update:
             smodel = self.list_view.selectionModel()
             for selected_index in event.removed:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Deselect)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Deselect,
+                )
             for selected_index in event.added:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Select)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Select,
+                )
 
-    #-- List Control Event Handlers ------------------------------------------
+    # -- List Control Event Handlers ------------------------------------------
 
     def _on_activate(self, mi):
         """ Handle a cell being activated.
@@ -365,7 +380,8 @@ class _ListStrEditor(Editor):
         if mi.isValid():
             self.right_clicked_index = index = mi.row()
             self.right_clicked = self.adapter.get_item(
-                self.object, self.name, index)
+                self.object, self.name, index
+            )
 
     def _on_row_selection(self, added, removed):
         """ Handle the row selection being changed.
@@ -375,8 +391,9 @@ class _ListStrEditor(Editor):
             indices = self.list_view.selectionModel().selectedRows()
             if len(indices):
                 self.selected_index = indices[0].row()
-                self.selected = self.adapter.get_item(self.object, self.name,
-                                                      self.selected_index)
+                self.selected = self.adapter.get_item(
+                    self.object, self.name, self.selected_index
+                )
             else:
                 self.selected_index = -1
                 self.selected = None
@@ -390,9 +407,10 @@ class _ListStrEditor(Editor):
         try:
             indices = self.list_view.selectionModel().selectedRows()
             self.multi_selected_indices = indices = [i.row() for i in indices]
-            self.multi_selected = [self.adapter.get_item(self.object,
-                                                         self.name, i)
-                                   for i in self.multi_selected_indices]
+            self.multi_selected = [
+                self.adapter.get_item(self.object, self.name, i)
+                for i in self.multi_selected_indices
+            ]
         finally:
             self._no_update = False
 
@@ -410,20 +428,23 @@ class _ListStrEditor(Editor):
         if menu is not None:
             qmenu = menu.create_menu(self.list_view, self)
 
-            self._menu_context = {'selection': self.object,
-                                  'object': self.object,
-                                  'editor': self,
-                                  'index': index,
-                                  'info': self.ui.info,
-                                  'handler': self.ui.handler}
+            self._menu_context = {
+                "selection": self.object,
+                "object": self.object,
+                "editor": self,
+                "index": index,
+                "info": self.ui.info,
+                "handler": self.ui.handler,
+            }
 
             qmenu.exec_(self.list_view.mapToGlobal(pos))
 
             self._menu_context = None
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Qt widgets that have been configured to behave as expected by Traits UI:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
@@ -445,8 +466,8 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
             painter.save()
             painter.setPen(option.palette.color(QtGui.QPalette.Dark))
             painter.drawLine(
-                option.rect.bottomLeft(),
-                option.rect.bottomRight())
+                option.rect.bottomLeft(), option.rect.bottomRight()
+            )
             painter.restore()
 
 
@@ -495,9 +516,12 @@ class _ListView(QtGui.QListView):
 
         # Note that setting 'EditKeyPressed' as an edit trigger does not work on
         # most platforms, which is why we do this here.
-        if (event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and
-            self.state() != QtGui.QAbstractItemView.EditingState and
-                factory.editable and 'edit' in factory.operations):
+        if (
+            event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
+            and self.state() != QtGui.QAbstractItemView.EditingState
+            and factory.editable
+            and "edit" in factory.operations
+        ):
             if factory.multi_select:
                 indices = editor.multi_selected_indices
                 row = indices[0] if len(indices) == 1 else -1
@@ -508,8 +532,11 @@ class _ListView(QtGui.QListView):
                 event.accept()
                 self.edit(editor.model.index(row))
 
-        elif (event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete) and
-              factory.editable and 'delete' in factory.operations):
+        elif (
+            event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete)
+            and factory.editable
+            and "delete" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
@@ -527,10 +554,14 @@ class _ListView(QtGui.QListView):
                 editor.model.removeRow(row)
                 # Handle the case of deleting the last item in the list.
                 editor.selected_index = min(
-                    row, editor.adapter.len(editor.object, editor.name) - 1)
+                    row, editor.adapter.len(editor.object, editor.name) - 1
+                )
 
-        elif (event.key() == QtCore.Qt.Key_Insert and
-              factory.editable and 'insert' in factory.operations):
+        elif (
+            event.key() == QtCore.Qt.Key_Insert
+            and factory.editable
+            and "insert" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
