@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,47 +8,36 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the various range editors and the range editor factory, for the
 PyQt user interface toolkit.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
-from math \
-    import log10
+from math import log10
 
 from pyface.qt import QtCore, QtGui
 
-from traits.api \
-    import TraitError, Str, Float, Any, Bool
+from traits.api import TraitError, Str, Float, Any, Bool
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.range_editor file.
-from traitsui.editors.range_editor \
-    import ToolkitEditorFactory
+from traitsui.editors.range_editor import ToolkitEditorFactory
 
-from .editor_factory \
-    import TextEditor
+from .editor_factory import TextEditor
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-from .constants \
-    import OKColor, ErrorColor
+from .constants import OKColor, ErrorColor
 
-from .helper \
-    import IconButton
-import six
+from .helper import IconButton
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'BaseRangeEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class BaseRangeEditor(Editor):
@@ -56,26 +45,18 @@ class BaseRangeEditor(Editor):
         when assigning numbers the object trait.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Function to evaluate floats/ints
-    evaluate = Any
-
-    #-------------------------------------------------------------------------
-    #  Sets the associated object trait's value:
-    #-------------------------------------------------------------------------
+    #: Function to evaluate floats/ints
+    evaluate = Any()
 
     def _set_value(self, value):
         if self.evaluate is not None:
             value = self.evaluate(value)
         Editor._set_value(self, value)
 
-#-------------------------------------------------------------------------
-#  'SimpleSliderEditor' class:
-#-------------------------------------------------------------------------
-
 
 class SimpleSliderEditor(BaseRangeEditor):
     """ Simple style of range editor that displays a slider and a text field.
@@ -84,23 +65,18 @@ class SimpleSliderEditor(BaseRangeEditor):
     in the text field.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Low value for the slider range
-    low = Any
+    #: Low value for the slider range
+    low = Any()
 
-    # High value for the slider range
-    high = Any
+    #: High value for the slider range
+    high = Any()
 
-    # Formatting string used to format value and labels
-    format = Str
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    #: Formatting string used to format value and labels
+    format = Str()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -116,10 +92,10 @@ class SimpleSliderEditor(BaseRangeEditor):
         self.format = factory.format
 
         self.evaluate = factory.evaluate
-        self.sync_value(factory.evaluate_name, 'evaluate', 'from')
+        self.sync_value(factory.evaluate_name, "evaluate", "from")
 
-        self.sync_value(factory.low_name, 'low', 'from')
-        self.sync_value(factory.high_name, 'high', 'from')
+        self.sync_value(factory.low_name, "low", "from")
+        self.sync_value(factory.high_name, "high", "from")
 
         self.control = QtGui.QWidget()
         panel = QtGui.QHBoxLayout(self.control)
@@ -132,14 +108,15 @@ class SimpleSliderEditor(BaseRangeEditor):
                 fvalue = self.low
             fvalue_text = self.format % fvalue
         except:
-            fvalue_text = ''
+            fvalue_text = ""
             fvalue = self.low
 
         ivalue = self._convert_to_slider(fvalue)
 
         self._label_lo = QtGui.QLabel()
-        self._label_lo.setAlignment(QtCore.Qt.AlignRight |
-                                    QtCore.Qt.AlignVCenter)
+        self._label_lo.setAlignment(
+            QtCore.Qt.AlignRight | QtCore.Qt.AlignVCenter
+        )
         if factory.label_width > 0:
             self._label_lo.setMinimumWidth(factory.label_width)
         panel.addWidget(self._label_lo)
@@ -170,11 +147,11 @@ class SimpleSliderEditor(BaseRangeEditor):
         panel.addWidget(text)
 
         low_label = factory.low_label
-        if factory.low_name != '':
+        if factory.low_name != "":
             low_label = self.format % self.low
 
         high_label = factory.high_label
-        if factory.high_name != '':
+        if factory.high_name != "":
             high_label = self.format % self.high
 
         self._label_lo.setText(low_label)
@@ -185,10 +162,6 @@ class SimpleSliderEditor(BaseRangeEditor):
         self.set_tooltip(self._label_hi)
         self.set_tooltip(text)
 
-    #-------------------------------------------------------------------------
-    #  Handles the user changing the current slider value:
-    #-------------------------------------------------------------------------
-
     def update_object_on_scroll(self, pos):
         """ Handles the user changing the current slider value.
         """
@@ -198,23 +171,24 @@ class SimpleSliderEditor(BaseRangeEditor):
             self.value = value
         except Exception as exc:
             from traitsui.api import raise_to_debug
-            raise_to_debug()
 
-    #-------------------------------------------------------------------------
-    #  Handle the user pressing the 'Enter' key in the edit control:
-    #-------------------------------------------------------------------------
+            raise_to_debug()
 
     def update_object_on_enter(self):
         """ Handles the user pressing the Enter key in the text field.
         """
+        # it is possible we get the event after the control has gone away
+        if self.control is None:
+            return
+
         try:
             try:
-                value = eval(six.text_type(self.control.text.text()).strip())
+                value = eval(str(self.control.text.text()).strip())
             except Exception as ex:
                 # The entered something that didn't eval as a number, (e.g.,
                 # 'foo') pretend it didn't happen
                 value = self.value
-                self.control.text.setText(six.text_type(value))
+                self.control.text.setText(str(value))
                 # for compound editor, value may be non-numeric
                 if not isinstance(value, (int, float)):
                     return
@@ -226,16 +200,13 @@ class SimpleSliderEditor(BaseRangeEditor):
             blocked = self.control.slider.blockSignals(True)
             try:
                 self.control.slider.setValue(
-                    self._convert_to_slider(self.value))
+                    self._convert_to_slider(self.value)
+                )
             finally:
                 self.control.slider.blockSignals(blocked)
         except TraitError as excp:
             pass
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -247,7 +218,7 @@ class SimpleSliderEditor(BaseRangeEditor):
             text = self.format % value
             1 / (low <= value <= high)
         except:
-            text = ''
+            text = ""
             value = low
 
         ivalue = self._convert_to_slider(value)
@@ -260,19 +231,11 @@ class SimpleSliderEditor(BaseRangeEditor):
         finally:
             self.control.slider.blockSignals(blocked)
 
-    #-------------------------------------------------------------------------
-    #  Returns the editor's control for indicating error status:
-    #-------------------------------------------------------------------------
-
     def get_error_control(self):
         """ Returns the editor's control for indicating error status.
         """
         return self.control.text
 
-    #-------------------------------------------------------------------------
-    #  Handles the 'low'/'high' traits being changed:
-    #-------------------------------------------------------------------------
-
     def _low_changed(self, low):
         if self.value < low:
             if self.factory.is_float:
@@ -299,8 +262,9 @@ class SimpleSliderEditor(BaseRangeEditor):
         """ Returns the slider setting corresponding to the user-supplied value.
         """
         if self.high > self.low:
-            ivalue = int((float(value - self.low) /
-                          (self.high - self.low)) * 10000.0)
+            ivalue = int(
+                (float(value - self.low) / (self.high - self.low)) * 10000.0
+            )
         else:
             ivalue = self.low
 
@@ -312,16 +276,15 @@ class SimpleSliderEditor(BaseRangeEditor):
         """ Returns the float or integer value corresponding to the slider
         setting.
         """
-        value = self.low + ((float(ivalue) / 10000.0) *
-                            (self.high - self.low))
+        value = self.low + ((float(ivalue) / 10000.0) * (self.high - self.low))
         if not self.factory.is_float:
             value = int(round(value))
         return value
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class LogRangeSliderEditor(SimpleSliderEditor):
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     """ A slider editor for log-spaced values
     """
 
@@ -329,8 +292,11 @@ class LogRangeSliderEditor(SimpleSliderEditor):
         """ Returns the slider setting corresponding to the user-supplied value.
         """
         value = max(value, self.low)
-        ivalue = int((log10(value) - log10(self.low)) /
-                     (log10(self.high) - log10(self.low)) * 10000.0)
+        ivalue = int(
+            (log10(value) - log10(self.low))
+            / (log10(self.high) - log10(self.low))
+            * 10000.0
+        )
         return ivalue
 
     def _convert_from_slider(self, ivalue):
@@ -340,15 +306,11 @@ class LogRangeSliderEditor(SimpleSliderEditor):
         value = float(ivalue) / 10000.0 * (log10(self.high) - log10(self.low))
         # Do this to handle floating point errors, where fvalue may exceed
         # self.high.
-        fvalue = min(self.low * 10**(value), self.high)
+        fvalue = min(self.low * 10 ** (value), self.high)
         if not self.factory.is_float:
             fvalue = int(round(fvalue))
         return fvalue
 
-#-------------------------------------------------------------------------
-#  'LargeRangeSliderEditor' class:
-#-------------------------------------------------------------------------
-
 
 class LargeRangeSliderEditor(BaseRangeEditor):
     """ A slider editor for large ranges.
@@ -357,30 +319,26 @@ class LargeRangeSliderEditor(BaseRangeEditor):
     is displayed in the slider; arrow buttons at each end of the slider let
     the user move the displayed range higher or lower.
     """
-    #-------------------------------------------------------------------------
-    #  Trait definitions:
-    #-------------------------------------------------------------------------
 
-    # Low value for the slider range
+    # -------------------------------------------------------------------------
+    #  Trait definitions:
+    # -------------------------------------------------------------------------
+
+    #: Low value for the slider range
     low = Any(0)
 
-    # High value for the slider range
+    #: High value for the slider range
     high = Any(1)
 
-    # Low end of displayed range
-    cur_low = Float
+    #: Low end of displayed range
+    cur_low = Float()
 
-    # High end of displayed range
-    cur_high = Float
+    #: High end of displayed range
+    cur_high = Float()
 
-    # Flag indicating that the UI is in the process of being updated
+    #: Flag indicating that the UI is in the process of being updated
     ui_changing = Bool(False)
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -393,9 +351,9 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         self.evaluate = factory.evaluate
 
         # Hook up the traits to listen to the object.
-        self.sync_value(factory.low_name, 'low', 'from')
-        self.sync_value(factory.high_name, 'high', 'from')
-        self.sync_value(factory.evaluate_name, 'evaluate', 'from')
+        self.sync_value(factory.low_name, "low", "from")
+        self.sync_value(factory.high_name, "high", "from")
+        self.sync_value(factory.evaluate_name, "evaluate", "from")
 
         self.init_range()
         low = self.cur_low
@@ -413,7 +371,7 @@ class LargeRangeSliderEditor(BaseRangeEditor):
             fvalue_text = self._format % fvalue
             1 / (low <= fvalue <= high)
         except:
-            fvalue_text = ''
+            fvalue_text = ""
             fvalue = low
 
         if high > low:
@@ -427,8 +385,9 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         panel.addWidget(label_lo)
 
         # Lower limit button:
-        self.control.button_lo = IconButton(QtGui.QStyle.SP_ArrowLeft,
-                                            self.reduce_range)
+        self.control.button_lo = IconButton(
+            QtGui.QStyle.SP_ArrowLeft, self.reduce_range
+        )
         panel.addWidget(self.control.button_lo)
 
         # Slider:
@@ -443,8 +402,9 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         panel.addWidget(slider)
 
         # Upper limit button:
-        self.control.button_hi = IconButton(QtGui.QStyle.SP_ArrowRight,
-                                            self.increase_range)
+        self.control.button_hi = IconButton(
+            QtGui.QStyle.SP_ArrowRight, self.increase_range
+        )
         panel.addWidget(self.control.button_hi)
 
         # Upper limit label:
@@ -472,15 +432,12 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         # Update the ranges and button just in case.
         self.update_range_ui()
 
-    #-------------------------------------------------------------------------
-    #  Handles the user changing the current slider value:
-    #-------------------------------------------------------------------------
-
     def update_object_on_scroll(self, pos):
         """ Handles the user changing the current slider value.
         """
-        value = self.cur_low + ((float(pos) / 10000.0)
-                                * (self.cur_high - self.cur_low))
+        value = self.cur_low + (
+            (float(pos) / 10000.0) * (self.cur_high - self.cur_low)
+        )
 
         self.control.text.setText(self._format % value)
 
@@ -489,22 +446,14 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         else:
             self.value = int(value)
 
-    #-------------------------------------------------------------------------
-    #  Handle the user pressing the 'Enter' key in the edit control:
-    #-------------------------------------------------------------------------
-
     def update_object_on_enter(self):
         """ Handles the user pressing the Enter key in the text field.
         """
         try:
-            self.value = eval(six.text_type(self.control.text.text()).strip())
+            self.value = eval(str(self.control.text.text()).strip())
         except TraitError as excp:
             pass
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -559,7 +508,7 @@ class LargeRangeSliderEditor(BaseRangeEditor):
             cur_low = max(value - 10, low)
             cur_high = min(value + 10, high)
         else:
-            d = 0.5 * (10**int(log10(mag) + 1))
+            d = 0.5 * (10 ** int(log10(mag) + 1))
             cur_low = max(low, value - d)
             cur_high = min(high, value + d)
 
@@ -604,32 +553,23 @@ class LargeRangeSliderEditor(BaseRangeEditor):
         self.update_range_ui()
 
     def _set_format(self):
-        self._format = '%d'
+        self._format = "%d"
         factory = self.factory
         low, high = self.cur_low, self.cur_high
         diff = high - low
         if factory.is_float:
             if diff > 99999:
-                self._format = '%.2g'
+                self._format = "%.2g"
             elif diff > 1:
-                self._format = '%%.%df' % max(0, 4 -
-                                              int(log10(high - low)))
+                self._format = "%%.%df" % max(0, 4 - int(log10(high - low)))
             else:
-                self._format = '%.3f'
-
-    #-------------------------------------------------------------------------
-    #  Returns the editor's control for indicating error status:
-    #-------------------------------------------------------------------------
+                self._format = "%.3f"
 
     def get_error_control(self):
         """ Returns the editor's control for indicating error status.
         """
         return self.control.text
 
-    #-------------------------------------------------------------------------
-    #  Handles the 'low'/'high' traits being changed:
-    #-------------------------------------------------------------------------
-
     def _low_changed(self, low):
         if self.control is not None:
             if self.value < low:
@@ -650,28 +590,20 @@ class LargeRangeSliderEditor(BaseRangeEditor):
 
             self.update_editor()
 
-#-------------------------------------------------------------------------
-#  'SimpleSpinEditor' class:
-#-------------------------------------------------------------------------
-
 
 class SimpleSpinEditor(BaseRangeEditor):
     """ A simple style of range editor that displays a spin box control.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     # Low value for the slider range
-    low = Any
+    low = Any()
 
     # High value for the slider range
-    high = Any
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    high = Any()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -684,8 +616,8 @@ class SimpleSpinEditor(BaseRangeEditor):
         if not factory.high_name:
             self.high = factory.high
 
-        self.sync_value(factory.low_name, 'low', 'from')
-        self.sync_value(factory.high_name, 'high', 'from')
+        self.sync_value(factory.low_name, "low", "from")
+        self.sync_value(factory.high_name, "high", "from")
         low = self.low
         high = self.high
 
@@ -696,10 +628,6 @@ class SimpleSpinEditor(BaseRangeEditor):
         self.control.valueChanged.connect(self.update_object)
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
-    #  Handle the user selecting a new value from the spin control:
-    #-------------------------------------------------------------------------
-
     def update_object(self, value):
         """ Handles the user selecting a new value in the spin box.
         """
@@ -709,10 +637,6 @@ class SimpleSpinEditor(BaseRangeEditor):
         finally:
             self._locked = False
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -723,14 +647,11 @@ class SimpleSpinEditor(BaseRangeEditor):
                 self.control.setValue(int(self.value))
             except Exception:
                 from traitsui.api import raise_to_debug
+
                 raise_to_debug()
             finally:
                 self.control.blockSignals(blocked)
 
-    #-------------------------------------------------------------------------
-    #  Handles the 'low'/'high' traits being changed:
-    #-------------------------------------------------------------------------
-
     def _low_changed(self, low):
         if self.value < low:
             if self.factory.is_float:
@@ -753,10 +674,6 @@ class SimpleSpinEditor(BaseRangeEditor):
             self.control.setMaximum(high)
             self.control.setValue(int(self.value))
 
-#-------------------------------------------------------------------------
-#  'RangeTextEditor' class:
-#-------------------------------------------------------------------------
-
 
 class RangeTextEditor(TextEditor):
     """ Editor for ranges that displays a text field. If the user enters a
@@ -764,17 +681,12 @@ class RangeTextEditor(TextEditor):
     changes color to indicate an error.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Function to evaluate floats/ints
-    evaluate = Any
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    #: Function to evaluate floats/ints
+    evaluate = Any()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -782,17 +694,13 @@ class RangeTextEditor(TextEditor):
         """
         TextEditor.init(self, parent)
         self.evaluate = self.factory.evaluate
-        self.sync_value(self.factory.evaluate_name, 'evaluate', 'from')
-
-    #-------------------------------------------------------------------------
-    #  Handles the user entering input data in the edit control:
-    #-------------------------------------------------------------------------
+        self.sync_value(self.factory.evaluate_name, "evaluate", "from")
 
     def update_object(self):
         """ Handles the user entering input data in the edit control.
         """
         try:
-            value = eval(six.text_type(self.control.text()))
+            value = eval(str(self.control.text()))
             if self.evaluate is not None:
                 value = self.evaluate(value)
             self.value = value
@@ -805,56 +713,59 @@ class RangeTextEditor(TextEditor):
             pal.setColor(QtGui.QPalette.Base, col)
             self.control.setPalette(pal)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'SimpleEnumEditor' factory adaptor:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 def SimpleEnumEditor(parent, factory, ui, object, name, description):
-    return CustomEnumEditor(parent, factory, ui, object, name, description,
-                            'simple')
-
-#-------------------------------------------------------------------------
-#  'CustomEnumEditor' factory adaptor:
-#-------------------------------------------------------------------------
+    return CustomEnumEditor(
+        parent, factory, ui, object, name, description, "simple"
+    )
 
 
-def CustomEnumEditor(parent, factory, ui, object, name, description,
-                     style='custom'):
+def CustomEnumEditor(
+    parent, factory, ui, object, name, description, style="custom"
+):
     """ Factory adapter that returns a enumeration editor of the specified
     style.
     """
     if factory._enum is None:
         import traitsui.editors.enum_editor as enum_editor
+
         factory._enum = enum_editor.ToolkitEditorFactory(
             values=list(range(factory.low, factory.high + 1)),
-            cols=factory.cols)
+            cols=factory.cols,
+        )
 
-    if style == 'simple':
-        return factory._enum.simple_editor(ui, object, name, description,
-                                           parent)
+    if style == "simple":
+        return factory._enum.simple_editor(
+            ui, object, name, description, parent
+        )
 
     return factory._enum.custom_editor(ui, object, name, description, parent)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Defines the mapping between editor factory 'mode's and Editor classes:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Mapping between editor factory modes and simple editor classes
 SimpleEditorMap = {
-    'slider': SimpleSliderEditor,
-    'xslider': LargeRangeSliderEditor,
-    'spinner': SimpleSpinEditor,
-    'enum': SimpleEnumEditor,
-    'text': RangeTextEditor,
-    'logslider': LogRangeSliderEditor
+    "slider": SimpleSliderEditor,
+    "xslider": LargeRangeSliderEditor,
+    "spinner": SimpleSpinEditor,
+    "enum": SimpleEnumEditor,
+    "text": RangeTextEditor,
+    "logslider": LogRangeSliderEditor,
 }
 # Mapping between editor factory modes and custom editor classes
 CustomEditorMap = {
-    'slider': SimpleSliderEditor,
-    'xslider': LargeRangeSliderEditor,
-    'spinner': SimpleSpinEditor,
-    'enum': CustomEnumEditor,
-    'text': RangeTextEditor,
-    'logslider': LogRangeSliderEditor
+    "slider": SimpleSliderEditor,
+    "xslider": LargeRangeSliderEditor,
+    "spinner": SimpleSpinEditor,
+    "enum": CustomEnumEditor,
+    "text": RangeTextEditor,
+    "logslider": LogRangeSliderEditor,
 }
