@@ -1,17 +1,17 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2012, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Author: Pietro Berkes
 #  Date:   Jan 2012
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """
 Test case for bug (wx, Mac OS X)
@@ -20,7 +20,6 @@ A RangeEditor in mode 'text' for an Int allows values out of range.
 """
 
 
-
 from traits.has_traits import HasTraits
 from traits.trait_types import Float, Int
 from traitsui.item import Item
@@ -34,12 +33,12 @@ class NumberWithRangeEditor(HasTraits):
     """Dialog containing a RangeEditor in 'spinner' mode for an Int.
     """
 
-    number = Int
+    number = Int()
 
     traits_view = View(
         Item(label="Range should be 3 to 8. Enter 1, then press OK"),
-        Item('number', editor=RangeEditor(low=3, high=8, mode='text')),
-        buttons=['OK']
+        Item("number", editor=RangeEditor(low=3, high=8, mode="text")),
+        buttons=["OK"],
     )
 
 
@@ -50,8 +49,7 @@ class FloatWithRangeEditor(HasTraits):
     number = Float(5.0)
 
     traits_view = View(
-        Item('number', editor=RangeEditor(low=0.0, high=12.0)),
-        buttons=['OK']
+        Item("number", editor=RangeEditor(low=0.0, high=12.0)), buttons=["OK"]
     )
 
 
@@ -68,8 +66,8 @@ def test_wx_text_editing():
         # the following is equivalent to setting the text in the text control,
         # then pressing OK
 
-        textctrl = ui.control.FindWindowByName('text')
-        textctrl.SetValue('1')
+        textctrl = ui.control.FindWindowByName("text")
+        textctrl.SetValue("1")
 
         # press the OK button and close the dialog
         press_ok_button(ui)
@@ -93,18 +91,18 @@ def test_avoid_slider_feedback():
         # then pressing OK
         lineedit = ui.control.findChild(qt.QtGui.QLineEdit)
         lineedit.setFocus()
-        lineedit.setText('4')
+        lineedit.setText("4")
         lineedit.editingFinished.emit()
 
         # press the OK button and close the dialog
         press_ok_button(ui)
 
     # the number trait should be 4 extactly
-    print (num.number)
+    print(num.number)
     assert num.number == 4.0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # Executing the file opens the dialog for manual testing
     num = NumberWithTextEditor()
     num.configure_traits()
