@@ -1,30 +1,32 @@
-from __future__ import absolute_import
 
 from pyface.gui import GUI
 from traits.api import HasTraits, Instance, Int, List, Str, Tuple
 
-from traitsui.api import (
-    EvalTableFilter, Item, ObjectColumn, TableEditor, View
-)
+from traitsui.api import EvalTableFilter, Item, ObjectColumn, TableEditor, View
 from traitsui.tests._tools import (
-    is_current_backend_qt4, is_current_backend_wx, press_ok_button,
-    skip_if_not_qt4,  skip_if_null, store_exceptions_on_all_threads
+    is_current_backend_qt4,
+    is_current_backend_wx,
+    press_ok_button,
+    skip_if_not_qt4,
+    skip_if_null,
+    store_exceptions_on_all_threads,
 )
 
 
 class ListItem(HasTraits):
     """ Items to visualize in a table editor """
-    value = Str
-    other_value = Int
+
+    value = Str()
+    other_value = Int()
 
 
 class ObjectListWithSelection(HasTraits):
     values = List(Instance(ListItem))
     selected = Instance(ListItem)
     selections = List(Instance(ListItem))
-    selected_index = Int
+    selected_index = Int()
     selected_indices = List(Int)
-    selected_column = Str
+    selected_column = Str()
     selected_columns = List(Str)
     selected_cell = Tuple(Instance(ListItem), Str)
     selected_cells = List(Tuple(Instance(ListItem), Str))
@@ -38,222 +40,220 @@ class ObjectList(HasTraits):
 
 simple_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
-            ],
-        )
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
+            ]
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 filtered_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            filter=EvalTableFilter(expression='other_value >= 2'),
-        )
+            filter=EvalTableFilter(expression="other_value >= 2"),
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_row_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='row',
-            selected='selected',
-        )
+            selection_mode="row",
+            selected="selected",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_rows_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
-            columns=[
-                ObjectColumn(name='value'),
-            ],
-            selection_mode='rows',
-            selected='selections',
-        )
+            columns=[ObjectColumn(name="value")],
+            selection_mode="rows",
+            selected="selections",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_row_index_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='row',
-            selected_indices='selected_index',
-        )
+            selection_mode="row",
+            selected_indices="selected_index",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_row_indices_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='rows',
-            selected_indices='selected_indices',
-        )
+            selection_mode="rows",
+            selected_indices="selected_indices",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_column_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='column',
-            selected='selected_column',
-        )
+            selection_mode="column",
+            selected="selected_column",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_columns_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='columns',
-            selected='selected_columns',
-        )
+            selection_mode="columns",
+            selected="selected_columns",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_column_index_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='column',
-            selected_indices='selected_index',
-        )
+            selection_mode="column",
+            selected_indices="selected_index",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_column_indices_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='columns',
-            selected_indices='selected_indices',
-        )
+            selection_mode="columns",
+            selected_indices="selected_indices",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_cell_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='cell',
-            selected='selected_cell',
-        )
+            selection_mode="cell",
+            selected="selected_cell",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_cells_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='cells',
-            selected='selected_cells',
-        )
+            selection_mode="cells",
+            selected="selected_cells",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_cell_index_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='cell',
-            selected_indices='selected_cell_index',
-        )
+            selection_mode="cell",
+            selected_indices="selected_cell_index",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 select_cell_indices_view = View(
     Item(
-        'values',
+        "values",
         show_label=False,
         editor=TableEditor(
             columns=[
-                ObjectColumn(name='value'),
-                ObjectColumn(name='other_value'),
+                ObjectColumn(name="value"),
+                ObjectColumn(name="other_value"),
             ],
-            selection_mode='cells',
-            selected_indices='selected_cell_indices',
-        )
+            selection_mode="cells",
+            selected_indices="selected_cell_indices",
+        ),
     ),
-    buttons=['OK'],
+    buttons=["OK"],
 )
 
 
@@ -261,7 +261,7 @@ select_cell_indices_view = View(
 def test_table_editor():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
 
     with store_exceptions_on_all_threads():
@@ -275,14 +275,14 @@ def test_table_editor():
 def test_filtered_table_editor():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=filtered_view)
         gui.process_events()
 
-        filter = ui.get_editors('values')[0].filter
+        filter = ui.get_editors("values")[0].filter
 
         press_ok_button(ui)
         gui.process_events()
@@ -294,13 +294,13 @@ def test_filtered_table_editor():
 def test_table_editor_select_row():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected = object_list.values[5]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_row_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -317,13 +317,13 @@ def test_table_editor_select_row():
 def test_table_editor_select_rows():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selections = object_list.values[5:7]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_rows_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -340,13 +340,13 @@ def test_table_editor_select_rows():
 def test_table_editor_select_row_index():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_index = 5
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_row_index_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -363,13 +363,13 @@ def test_table_editor_select_row_index():
 def test_table_editor_select_row_indices():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_indices = [5, 7, 8]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_row_indices_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -386,13 +386,13 @@ def test_table_editor_select_row_indices():
 def test_table_editor_select_column():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
-    object_list.selected_column = 'value'
+    object_list.selected_column = "value"
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_column_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -402,20 +402,20 @@ def test_table_editor_select_column():
         press_ok_button(ui)
         gui.process_events()
 
-    assert selected == 'value'
+    assert selected == "value"
 
 
 @skip_if_null
 def test_table_editor_select_columns():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
-    object_list.selected_columns = ['value', 'other_value']
+    object_list.selected_columns = ["value", "other_value"]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_columns_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -425,20 +425,20 @@ def test_table_editor_select_columns():
         press_ok_button(ui)
         gui.process_events()
 
-    assert selected == ['value', 'other_value']
+    assert selected == ["value", "other_value"]
 
 
 @skip_if_null
 def test_table_editor_select_column_index():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_index = 1
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_column_index_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -455,13 +455,13 @@ def test_table_editor_select_column_index():
 def test_table_editor_select_column_indices():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_indices = [0, 1]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_column_indices_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -478,13 +478,13 @@ def test_table_editor_select_column_indices():
 def test_table_editor_select_cell():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
-    object_list.selected_cell = (object_list.values[5], 'value')
+    object_list.selected_cell = (object_list.values[5], "value")
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_cell_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -494,24 +494,24 @@ def test_table_editor_select_cell():
         press_ok_button(ui)
         gui.process_events()
 
-    assert selected == (object_list.values[5], 'value')
+    assert selected == (object_list.values[5], "value")
 
 
 @skip_if_null
 def test_table_editor_select_cells():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_cells = [
-        (object_list.values[5], 'value'),
-        (object_list.values[6], 'other value'),
-        (object_list.values[8], 'value'),
+        (object_list.values[5], "value"),
+        (object_list.values[6], "other value"),
+        (object_list.values[8], "value"),
     ]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_cells_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected
@@ -522,9 +522,9 @@ def test_table_editor_select_cells():
         gui.process_events()
 
     assert selected == [
-        (object_list.values[5], 'value'),
-        (object_list.values[6], 'other value'),
-        (object_list.values[8], 'value'),
+        (object_list.values[5], "value"),
+        (object_list.values[6], "other value"),
+        (object_list.values[8], "value"),
     ]
 
 
@@ -532,13 +532,13 @@ def test_table_editor_select_cells():
 def test_table_editor_select_cell_index():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_cell_index = (5, 1)
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_cell_index_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -555,13 +555,13 @@ def test_table_editor_select_cell_index():
 def test_table_editor_select_cell_indices():
     gui = GUI()
     object_list = ObjectListWithSelection(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
     object_list.selected_cell_indices = [(5, 0), (6, 1), (8, 0)]
 
     with store_exceptions_on_all_threads():
         ui = object_list.edit_traits(view=select_cell_indices_view)
-        editor = ui.get_editors('values')[0]
+        editor = ui.get_editors("values")[0]
         gui.process_events()
         if is_current_backend_qt4():
             selected = editor.selected_indices
@@ -577,22 +577,23 @@ def test_table_editor_select_cell_indices():
 @skip_if_not_qt4
 def test_progress_column():
     from traitsui.extras.progress_column import ProgressColumn
+
     progress_view = View(
         Item(
-            'values',
+            "values",
             show_label=False,
             editor=TableEditor(
                 columns=[
-                    ObjectColumn(name='value'),
-                    ProgressColumn(name='other_value'),
-                ],
-            )
+                    ObjectColumn(name="value"),
+                    ProgressColumn(name="other_value"),
+                ]
+            ),
         ),
-        buttons=['OK'],
+        buttons=["OK"],
     )
     gui = GUI()
     object_list = ObjectList(
-        values=[ListItem(value=str(i**2)) for i in range(10)]
+        values=[ListItem(value=str(i ** 2)) for i in range(10)]
     )
 
     with store_exceptions_on_all_threads():
