@@ -3,7 +3,7 @@
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -22,7 +22,7 @@ from traitsui.api import Controller
 
 
 class FooModel(HasTraits):
-    my_str = Str('hallo')
+    my_str = Str("hallo")
 
 
 class FooController(Controller):
@@ -31,14 +31,14 @@ class FooController(Controller):
     model = Instance(FooModel)
 
     def _model_default(self):
-        return FooModel(my_str='meh')
+        return FooModel(my_str="meh")
 
 
 def test_construction():
     # check default constructor.
     dialog = FooController()
     nose.tools.assert_is_not_none(dialog.model)
-    nose.tools.assert_equal(dialog.model.my_str, 'meh')
+    nose.tools.assert_equal(dialog.model.my_str, "meh")
 
     # check initialization when `model` is explcitly passed in.
     new_model = FooModel()
