@@ -3,7 +3,7 @@
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -11,22 +11,27 @@
 #  Date:   Aug 2017
 #
 
-from __future__ import absolute_import
 from unittest import TestCase
 
 from pyface.action.api import ActionEvent
 from traits.api import HasTraits, Bool
 from traitsui.api import (
-    Action, CloseAction, Handler, HelpAction, RedoAction, RevertAction, UI,
-    UndoAction
+    Action,
+    CloseAction,
+    Handler,
+    HelpAction,
+    RedoAction,
+    RevertAction,
+    UI,
+    UndoAction,
 )
 
 
 class PyfaceAction(Action):
 
-    name = 'Test Action'
+    name = "Test Action"
 
-    performed = Bool
+    performed = Bool()
 
     def perform(self, event):
         self.performed = True
@@ -34,9 +39,9 @@ class PyfaceAction(Action):
 
 class TraitsUIAction(Action):
 
-    name = 'Test Action'
+    name = "Test Action"
 
-    performed = Bool
+    performed = Bool()
 
     def perform(self):
         self.performed = True
@@ -44,23 +49,23 @@ class TraitsUIAction(Action):
 
 class SampleHandler(Handler):
 
-    action_performed = Bool
+    action_performed = Bool()
 
-    info_action_performed = Bool
+    info_action_performed = Bool()
 
-    click_performed = Bool
+    click_performed = Bool()
 
-    undo_performed = Bool
+    undo_performed = Bool()
 
-    redo_performed = Bool
+    redo_performed = Bool()
 
-    revert_performed = Bool
+    revert_performed = Bool()
 
-    apply_performed = Bool
+    apply_performed = Bool()
 
-    close_performed = Bool
+    close_performed = Bool()
 
-    help_performed = Bool
+    help_performed = Bool()
 
     def action_handler(self):
         self.action_performed = True
@@ -99,13 +104,13 @@ class SampleHandler(Handler):
 
 class SampleObject(HasTraits):
 
-    object_action_performed = Bool
+    object_action_performed = Bool()
 
-    action_performed = Bool
+    action_performed = Bool()
 
-    info_action_performed = Bool
+    info_action_performed = Bool()
 
-    click_performed = Bool
+    click_performed = Bool()
 
     def object_action_handler(self):
         self.object_action_performed = True
@@ -121,13 +126,12 @@ class SampleObject(HasTraits):
 
 
 class TestHandler(TestCase):
-
     def test_perform_pyface_action(self):
         object = SampleObject()
         handler = SampleHandler()
         action = PyfaceAction()
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -139,7 +143,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = TraitsUIAction()
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -155,9 +159,9 @@ class TestHandler(TestCase):
     def test_perform_action_handler(self):
         object = SampleObject()
         handler = SampleHandler()
-        action = TraitsUIAction(name='action', action='action_handler')
+        action = TraitsUIAction(name="action", action="action_handler")
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -173,9 +177,9 @@ class TestHandler(TestCase):
     def test_perform_info_action_handler(self):
         object = SampleObject()
         handler = SampleHandler()
-        action = TraitsUIAction(name='action', action='info_action_handler')
+        action = TraitsUIAction(name="action", action="info_action_handler")
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -191,9 +195,9 @@ class TestHandler(TestCase):
     def test_perform_click_handler(self):
         object = SampleObject()
         handler = SampleHandler()
-        action = TraitsUIAction(name='action', action='')
+        action = TraitsUIAction(name="action", action="")
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -209,9 +213,9 @@ class TestHandler(TestCase):
     def test_perform_object_handler(self):
         object = SampleObject()
         handler = SampleHandler()
-        action = TraitsUIAction(name='action', action='object_action_handler')
+        action = TraitsUIAction(name="action", action="object_action_handler")
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -224,7 +228,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = UndoAction
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -236,7 +240,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = RedoAction
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -248,7 +252,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = RevertAction
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -260,7 +264,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = CloseAction
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
@@ -272,7 +276,7 @@ class TestHandler(TestCase):
         handler = SampleHandler()
         action = HelpAction
         event = ActionEvent()
-        ui = UI(handler=handler, context={'object': object})
+        ui = UI(handler=handler, context={"object": object})
         info = ui.info
 
         handler.perform(info, action, event)
