@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,89 +13,75 @@
 #  Author: David C. Morrill
 #  Date:   10/07/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the manager for Undo and Redo history for Traits user interface
     support.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 import collections
 
-from traits.api import (Event, HasPrivateTraits, HasStrictTraits, HasTraits,
-                        Instance, Int, List, Property, Str, Trait)
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
-NumericTypes = (int, int, float, complex)
-SimpleTypes = (str, str, int, int, float, complex)
+from traits.api import (
+    Event,
+    HasPrivateTraits,
+    HasStrictTraits,
+    HasTraits,
+    Instance,
+    Int,
+    List,
+    Property,
+    Str,
+    Trait,
+)
 
-#-------------------------------------------------------------------------
-#  'AbstractUndoItem' class:
-#-------------------------------------------------------------------------
+
+NumericTypes = (int, float, complex)
+SimpleTypes = (str, bytes) + NumericTypes
 
 
 class AbstractUndoItem(HasPrivateTraits):
     """ Abstract base class for undo items.
     """
-    #-------------------------------------------------------------------------
-    #  Undoes the change:
-    #-------------------------------------------------------------------------
 
     def undo(self):
         """ Undoes the change.
         """
         raise NotImplementedError
 
-    #-------------------------------------------------------------------------
-    #  Re-does the change:
-    #-------------------------------------------------------------------------
-
     def redo(self):
         """ Re-does the change.
         """
         raise NotImplementedError
 
-    #-------------------------------------------------------------------------
-    #  Merges two undo items if possible:
-    #-------------------------------------------------------------------------
-
     def merge_undo(self, undo_item):
         """ Merges two undo items if possible.
         """
         return False
 
-#-------------------------------------------------------------------------
-#  'UndoItem' class:
-#-------------------------------------------------------------------------
-
 
 class UndoItem(AbstractUndoItem):
     """ A change to an object trait, which can be undone.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Object the change occurred on
-    object = Trait(HasTraits)
-    # Name of the trait that changed
-    name = Str
-    # Old value of the changed trait
-    old_value = Property
-    # New value of the changed trait
-    new_value = Property
+    #: Object the change occurred on
+    object = Instance(HasTraits)
 
-    #-------------------------------------------------------------------------
-    #  Implementation of the 'old_value' and 'new_value' properties:
-    #-------------------------------------------------------------------------
+    #: Name of the trait that changed
+    name = Str()
+
+    #: Old value of the changed trait
+    old_value = Property()
+
+    #: New value of the changed trait
+    new_value = Property()
 
     def _get_old_value(self):
         return self._old_value
@@ -113,42 +99,36 @@ class UndoItem(AbstractUndoItem):
             value = value[:]
         self._new_value = value
 
-    #-------------------------------------------------------------------------
-    #  Undoes the change:
-    #-------------------------------------------------------------------------
-
     def undo(self):
         """ Undoes the change.
         """
         try:
             setattr(self.object, self.name, self.old_value)
-        except:
-            pass
+        except Exception:
+            from traitsui.api import raise_to_debug
 
-    #-------------------------------------------------------------------------
-    #  Re-does the change:
-    #-------------------------------------------------------------------------
+            raise_to_debug()
 
     def redo(self):
         """ Re-does the change.
         """
         try:
             setattr(self.object, self.name, self.new_value)
-        except:
-            pass
+        except Exception:
+            from traitsui.api import raise_to_debug
 
-    #-------------------------------------------------------------------------
-    #  Merges two undo items if possible:
-    #-------------------------------------------------------------------------
+            raise_to_debug()
 
     def merge_undo(self, undo_item):
         """ Merges two undo items if possible.
         """
         # Undo items are potentially mergeable only if they are of the same
         # class and refer to the same object trait, so check that first:
-        if (isinstance(undo_item, self.__class__) and
-            (self.object is undo_item.object) and
-                (self.name == undo_item.name)):
+        if (
+            isinstance(undo_item, self.__class__)
+            and (self.object is undo_item.object)
+            and (self.name == undo_item.name)
+        ):
             v1 = self.new_value
             v2 = undo_item.new_value
             t1 = type(v1)
@@ -161,11 +141,13 @@ class UndoItem(AbstractUndoItem):
                     # operation in a text editor):
                     n1 = len(v1)
                     n2 = len(v2)
+                    if abs(n1 - n2) > 1:
+                        return False
                     n = min(n1, n2)
                     i = 0
                     while (i < n) and (v1[i] == v2[i]):
                         i += 1
-                    if v1[i + (n2 <= n1):] == v2[i + (n2 >= n1):]:
+                    if v1[i + (n2 <= n1) :] == v2[i + (n2 >= n1) :]:
                         self.new_value = v2
                         return True
 
@@ -184,9 +166,11 @@ class UndoItem(AbstractUndoItem):
                                 for i, item in enumerate(v1):
                                     titem = type(item)
                                     item2 = v2[i]
-                                    if ((titem not in SimpleTypes) or
-                                        (not isinstance(item2, titem)) or
-                                            (item != item2)):
+                                    if (
+                                        (titem not in SimpleTypes)
+                                        or (not isinstance(item2, titem))
+                                        or (item != item2)
+                                    ):
                                         diffs += 1
                                         if diffs >= 2:
                                             return False
@@ -194,7 +178,7 @@ class UndoItem(AbstractUndoItem):
                                     return False
                                 self.new_value = v2
                                 return True
-                        except:
+                        except Exception:
                             pass
 
                 elif t1 in NumericTypes:
@@ -203,70 +187,65 @@ class UndoItem(AbstractUndoItem):
                     return True
         return False
 
-    #-------------------------------------------------------------------------
-    #  Returns a 'pretty print' form of the object:
-    #-------------------------------------------------------------------------
-
     def __repr__(self):
         """ Returns a "pretty print" form of the object.
         """
         n = self.name
         cn = self.object.__class__.__name__
-        return 'undo( %s.%s = %s )\nredo( %s.%s = %s )' % (
-            cn, n, self.old_value, cn, n, self.new_value)
-
-#-------------------------------------------------------------------------
-#  'ListUndoItem' class:
-#-------------------------------------------------------------------------
+        return "undo( %s.%s = %s )\nredo( %s.%s = %s )" % (
+            cn,
+            n,
+            self.old_value,
+            cn,
+            n,
+            self.new_value,
+        )
 
 
 class ListUndoItem(AbstractUndoItem):
     """ A change to a list, which can be undone.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Object that the change occurred on
-    object = Trait(HasTraits)
-    # Name of the trait that changed
-    name = Str
-    # Starting index
-    index = Int
-    # Items added to the list
-    added = List
-    # Items removed from the list
-    removed = List
+    #: Object that the change occurred on
+    object = Instance(HasTraits)
 
-    #-------------------------------------------------------------------------
-    #  Undoes the change:
-    #-------------------------------------------------------------------------
+    #: Name of the trait that changed
+    name = Str()
+
+    #: Starting index
+    index = Int()
+
+    #: Items added to the list
+    added = List()
+
+    #: Items removed from the list
+    removed = List()
 
     def undo(self):
         """ Undoes the change.
         """
         try:
             list = getattr(self.object, self.name)
-            list[self.index: (self.index + len(self.added))] = self.removed
-        except:
-            pass
+            list[self.index : (self.index + len(self.added))] = self.removed
+        except Exception:
+            from traitsui.api import raise_to_debug
 
-    #-------------------------------------------------------------------------
-    #  Re-does the change:
-    #-------------------------------------------------------------------------
+            raise_to_debug()
 
     def redo(self):
         """ Re-does the change.
         """
         try:
             list = getattr(self.object, self.name)
-            list[self.index: (self.index + len(self.removed))] = self.added
-        except:
-            pass
+            list[self.index : (self.index + len(self.removed))] = self.added
+        except Exception:
+            from traitsui.api import raise_to_debug
 
-    #-------------------------------------------------------------------------
-    #  Merges two undo items if possible:
-    #-------------------------------------------------------------------------
+            raise_to_debug()
 
     def merge_undo(self, undo_item):
         """ Merges two undo items if possible.
@@ -274,14 +253,17 @@ class ListUndoItem(AbstractUndoItem):
         # Discard undo items that are identical to us. This is to eliminate
         # the same undo item being created by multiple listeners monitoring the
         # same list for changes:
-        if (isinstance(undo_item, self.__class__) and
-            (self.object is undo_item.object) and
-            (self.name == undo_item.name) and
-                (self.index == undo_item.index)):
+        if (
+            isinstance(undo_item, self.__class__)
+            and (self.object is undo_item.object)
+            and (self.name == undo_item.name)
+            and (self.index == undo_item.index)
+        ):
             added = undo_item.added
             removed = undo_item.removed
-            if ((len(self.added) == len(added)) and
-                    (len(self.removed) == len(removed))):
+            if (len(self.added) == len(added)) and (
+                len(self.removed) == len(removed)
+            ):
                 for i, item in enumerate(self.added):
                     if item is not added[i]:
                         break
@@ -293,45 +275,38 @@ class ListUndoItem(AbstractUndoItem):
                         return True
         return False
 
-    #-------------------------------------------------------------------------
-    #  Returns a 'pretty print' form of the object:
-    #-------------------------------------------------------------------------
-
     def __repr__(self):
         """ Returns a 'pretty print' form of the object.
         """
-        return 'undo( %s.%s[%d:%d] = %s )' % (
-            self.object.__class__.__name__, self.name, self.index,
-            self.index + len(self.removed), self.added)
-
-#-------------------------------------------------------------------------
-#  'UndoHistory' class:
-#-------------------------------------------------------------------------
+        return "undo( %s.%s[%d:%d] = %s )" % (
+            self.object.__class__.__name__,
+            self.name,
+            self.index,
+            self.index + len(self.removed),
+            self.added,
+        )
 
 
 class UndoHistory(HasStrictTraits):
     """ Manages a list of undoable changes.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # List of accumulated undo changes
-    history = List
-    # The current position in the list
-    now = Int
-    # Fired when state changes to undoable
+    #: List of accumulated undo changes
+    history = List()
+    #: The current position in the list
+    now = Int()
+    #: Fired when state changes to undoable
     undoable = Event(False)
-    # Fired when state changes to redoable
+    #: Fired when state changes to redoable
     redoable = Event(False)
-    # Can an action be undone?
-    can_undo = Property
-    # Can an action be redone?
-    can_redo = Property
-
-    #-------------------------------------------------------------------------
-    #  Adds an UndoItem to the history:
-    #-------------------------------------------------------------------------
+    #: Can an action be undone?
+    can_undo = Property()
+    #: Can an action be redone?
+    can_redo = Property()
 
     def add(self, undo_item, extend=False):
         """ Adds an UndoItem to the history.
@@ -356,10 +331,6 @@ class UndoHistory(HasStrictTraits):
         if self.now <= old_len:
             self.redoable = False
 
-    #-------------------------------------------------------------------------
-    #  Extends the most recent 'undo' item:
-    #-------------------------------------------------------------------------
-
     def extend(self, undo_item):
         """ Extends the undo history.
 
@@ -371,10 +342,6 @@ class UndoHistory(HasStrictTraits):
             if not undo_list[-1].merge_undo(undo_item):
                 undo_list.append(undo_item)
 
-    #-------------------------------------------------------------------------
-    #  Undo an operation:
-    #-------------------------------------------------------------------------
-
     def undo(self):
         """ Undoes an operation.
         """
@@ -388,10 +355,6 @@ class UndoHistory(HasStrictTraits):
             if self.now == (len(self.history) - 1):
                 self.redoable = True
 
-    #-------------------------------------------------------------------------
-    #  Redo an operation:
-    #-------------------------------------------------------------------------
-
     def redo(self):
         """ Redoes an operation.
         """
@@ -404,10 +367,6 @@ class UndoHistory(HasStrictTraits):
             if self.now == len(self.history):
                 self.redoable = False
 
-    #-------------------------------------------------------------------------
-    #  Reverts all changes made so far and clears the history:
-    #-------------------------------------------------------------------------
-
     def revert(self):
         """ Reverts all changes made so far and clears the history.
         """
@@ -418,10 +377,6 @@ class UndoHistory(HasStrictTraits):
             for j in range(len(items) - 1, -1, -1):
                 items[j].undo()
 
-    #-------------------------------------------------------------------------
-    #  Clears the undo history
-    #-------------------------------------------------------------------------
-
     def clear(self):
         """ Clears the undo history.
         """
@@ -434,43 +389,28 @@ class UndoHistory(HasStrictTraits):
         if old_now < old_len:
             self.redoable = False
 
-    #-------------------------------------------------------------------------
-    #  Are there any undoable operations?
-    #-------------------------------------------------------------------------
-
     def _get_can_undo(self):
         """ Are there any undoable operations?
         """
         return self.now > 0
 
-    #-------------------------------------------------------------------------
-    #  Are there any redoable operations?
-    #-------------------------------------------------------------------------
-
     def _get_can_redo(self):
         """ Are there any redoable operations?
         """
         return self.now < len(self.history)
 
-#-------------------------------------------------------------------------
-#  'UndoHistoryUndoItem' class:
-#-------------------------------------------------------------------------
-
 
 class UndoHistoryUndoItem(AbstractUndoItem):
     """ An undo item for the undo history.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # The undo history to undo or redo
+    #: The undo history to undo or redo
     history = Instance(UndoHistory)
 
-    #-------------------------------------------------------------------------
-    #  Undoes the change:
-    #-------------------------------------------------------------------------
-
     def undo(self):
         """ Undoes the change.
         """
@@ -480,10 +420,6 @@ class UndoHistoryUndoItem(AbstractUndoItem):
             for j in range(len(items) - 1, -1, -1):
                 items[j].undo()
 
-    #-------------------------------------------------------------------------
-    #  Re-does the change:
-    #-------------------------------------------------------------------------
-
     def redo(self):
         """ Re-does the change.
         """
