@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -12,14 +12,16 @@
 #
 #  Author: David C. Morrill
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Table column object for Color traits.
 """
 
-from __future__ import absolute_import
 import warnings
-warnings.warn("traitsui.wx.color_column is deprecated. Use the "
-              "backend-independent implementation in traitsui.color_column")
+
+warnings.warn(
+    "traitsui.wx.color_column is deprecated. Use the "
+    "backend-independent implementation in traitsui.color_column"
+)
 
 from traitsui.color_column import ColorColumn
