@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,35 +13,32 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the various editors for single-selection enumerations, for the
 wxPython user interface toolkit.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 import wx
 
-from traits.api \
-    import Property
+from traits.api import Property
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.drop_editor file.
-from traitsui.editors.enum_editor \
-    import ToolkitEditorFactory
+from traitsui.editors.enum_editor import ToolkitEditorFactory
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-from .constants \
-    import OKColor, ErrorColor
+from .constants import OKColor, ErrorColor
 
-from .helper \
-    import enum_values_changed, TraitsUIPanel, disconnect, disconnect_no_id
+from .helper import (
+    enum_values_changed,
+    TraitsUIPanel,
+    disconnect,
+    disconnect_no_id,
+)
 from functools import reduce
 
 
@@ -49,50 +46,45 @@ from functools import reduce
 capitalize = lambda s: s.capitalize()
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'BaseEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class BaseEditor(Editor):
     """ Base class for enumeration editors.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Current set of enumeration names:
-    names = Property
+    #: Current set of enumeration names:
+    names = Property()
 
-    # Current mapping from names to values:
-    mapping = Property
+    #: Current mapping from names to values:
+    mapping = Property()
 
-    # Current inverse mapping from values to names:
-    inverse_mapping = Property
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    #: Current inverse mapping from values to names:
+    inverse_mapping = Property()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
         factory = self.factory
-        if factory.name != '':
-            self._object, self._name, self._value = \
-                self.parse_extended_name(factory.name)
+        if factory.name != "":
+            self._object, self._name, self._value = self.parse_extended_name(
+                factory.name
+            )
             self.values_changed()
-            self._object.on_trait_change(self._values_changed,
-                                         ' ' + self._name, dispatch='ui')
+            self._object.on_trait_change(
+                self._values_changed, " " + self._name, dispatch="ui"
+            )
         else:
-            factory.on_trait_change(self.rebuild_editor, 'values_modified',
-                                    dispatch='ui')
-
-    #-------------------------------------------------------------------------
-    #  Gets the current set of enumeration names:
-    #-------------------------------------------------------------------------
+            factory.on_trait_change(
+                self.rebuild_editor, "values_modified", dispatch="ui"
+            )
 
     def _get_names(self):
         """ Gets the current set of enumeration names.
@@ -102,10 +94,6 @@ class BaseEditor(Editor):
 
         return self._names
 
-    #-------------------------------------------------------------------------
-    #  Gets the current mapping:
-    #-------------------------------------------------------------------------
-
     def _get_mapping(self):
         """ Gets the current mapping.
         """
@@ -114,10 +102,6 @@ class BaseEditor(Editor):
 
         return self._mapping
 
-    #-------------------------------------------------------------------------
-    #  Gets the current inverse mapping:
-    #-------------------------------------------------------------------------
-
     def _get_inverse_mapping(self):
         """ Gets the current inverse mapping.
         """
@@ -126,30 +110,18 @@ class BaseEditor(Editor):
 
         return self._inverse_mapping
 
-    #-------------------------------------------------------------------------
-    #  Rebuilds the contents of the editor whenever the original factory
-    #  object's 'values' trait changes:
-    #-------------------------------------------------------------------------
-
     def rebuild_editor(self):
         """ Rebuilds the contents of the editor whenever the original factory
             object's **values** trait changes.
         """
         raise NotImplementedError
 
-    #-------------------------------------------------------------------------
-    #  Recomputes the cached data based on the underlying enumeration model:
-    #-------------------------------------------------------------------------
-
     def values_changed(self):
         """ Recomputes the cached data based on the underlying enumeration model.
         """
-        self._names, self._mapping, self._inverse_mapping = \
-            enum_values_changed(self._value())
-
-    #-------------------------------------------------------------------------
-    #  Handles the underlying object model's enumeration set being changed:
-    #-------------------------------------------------------------------------
+        self._names, self._mapping, self._inverse_mapping = enum_values_changed(
+            self._value()
+        )
 
     def _values_changed(self):
         """ Handles the underlying object model's enumeration set being changed.
@@ -157,36 +129,30 @@ class BaseEditor(Editor):
         self.values_changed()
         self.rebuild_editor()
 
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
-
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
         if self._object is not None:
-            self._object.on_trait_change(self._values_changed,
-                                         ' ' + self._name, remove=True)
+            self._object.on_trait_change(
+                self._values_changed, " " + self._name, remove=True
+            )
         else:
-            self.factory.on_trait_change(self.rebuild_editor,
-                                         'values_modified', remove=True)
+            self.factory.on_trait_change(
+                self.rebuild_editor, "values_modified", remove=True
+            )
 
         super(BaseEditor, self).dispose()
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'SimpleEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class SimpleEditor(BaseEditor):
     """ Simple style of enumeration editor, which displays a combo box.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -196,20 +162,26 @@ class SimpleEditor(BaseEditor):
         factory = self.factory
 
         if factory.evaluate is None:
-            self.control = control = wx.Choice(parent, -1, wx.Point(0, 0),
-                                               wx.Size(-1, -1), self.names)
-            wx.EVT_CHOICE(parent, self.control.GetId(), self.update_object)
+            self.control = control = wx.Choice(
+                parent, -1, wx.Point(0, 0), wx.Size(-1, -1), self.names
+            )
+            parent.Bind(wx.EVT_CHOICE, self.update_object, id=self.control.GetId())
         else:
-            self.control = control = wx.ComboBox(parent, -1, '',
-                                                 wx.Point(0, 0), wx.Size(-1, -1), self.names,
-                                                 style=wx.CB_DROPDOWN)
-            wx.EVT_COMBOBOX(parent, control.GetId(), self.update_object)
-            wx.EVT_TEXT_ENTER(parent, control.GetId(),
-                              self.update_text_object)
-            wx.EVT_KILL_FOCUS(control, self.on_kill_focus)
+            self.control = control = wx.ComboBox(
+                parent,
+                -1,
+                "",
+                wx.Point(0, 0),
+                wx.Size(-1, -1),
+                self.names,
+                style=wx.CB_DROPDOWN,
+            )
+            parent.Bind(wx.EVT_COMBOBOX, self.update_object, id=control.GetId())
+            parent.Bind(wx.EVT_TEXT_ENTER, self.update_text_object, id=control.GetId())
+            control.Bind(wx.EVT_KILL_FOCUS, self.on_kill_focus)
 
             if (not factory.is_grid_cell) and factory.auto_set:
-                wx.EVT_TEXT(parent, control.GetId(), self.update_text_object)
+                parent.Bind(wx.EVT_TEXT, self.update_text_object, id=control.GetId())
 
         self._no_enum_update = 0
         self.set_tooltip()
@@ -217,17 +189,14 @@ class SimpleEditor(BaseEditor):
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
-        disconnect(self.control,
-                   wx.EVT_COMBOBOX, wx.EVT_TEXT_ENTER, wx.EVT_TEXT)
+        disconnect(
+            self.control, wx.EVT_COMBOBOX, wx.EVT_TEXT_ENTER, wx.EVT_TEXT
+        )
 
         disconnect_no_id(self.control, wx.EVT_KILL_FOCUS)
 
         super(SimpleEditor, self).dispose()
 
-    #-------------------------------------------------------------------------
-    #  Handles the user selecting a new value from the combo box:
-    #-------------------------------------------------------------------------
-
     def update_object(self, event):
         """ Handles the user selecting a new value from the combo box.
         """
@@ -250,14 +219,11 @@ class SimpleEditor(BaseEditor):
 
         except:
             from traitsui.api import raise_to_debug
+
             raise_to_debug()
 
         self._no_enum_update -= 1
 
-    #-------------------------------------------------------------------------
-    #  Handles the user typing text into the combo box text entry field:
-    #-------------------------------------------------------------------------
-
     def update_text_object(self, event):
         """ Handles the user typing text into the combo box text entry field.
         """
@@ -281,20 +247,12 @@ class SimpleEditor(BaseEditor):
                 pass
             self._no_enum_update -= 1
 
-    #-------------------------------------------------------------------------
-    #  Handles the control losing the keyboard focus:
-    #-------------------------------------------------------------------------
-
     def on_kill_focus(self, event):
         """ Handles the control losing the keyboard focus.
         """
         self.update_text_object(event)
         event.Skip()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -303,7 +261,8 @@ class SimpleEditor(BaseEditor):
             if self.factory.evaluate is None:
                 try:
                     self.control.SetStringSelection(
-                        self.inverse_mapping[self.value])
+                        self.inverse_mapping[self.value]
+                    )
                 except:
                     pass
             else:
@@ -312,21 +271,12 @@ class SimpleEditor(BaseEditor):
                 except:
                     pass
 
-    #-------------------------------------------------------------------------
-    #  Handles an error that occurs while setting the object's trait value:
-    #-------------------------------------------------------------------------
-
     def error(self, excp):
         """ Handles an error that occurs while setting the object's trait value.
         """
         self.control.SetBackgroundColour(ErrorColor)
         self.control.Refresh()
 
-    #-------------------------------------------------------------------------
-    #  Rebuilds the contents of the editor whenever the original factory
-    #  object's 'values' trait changes:
-    #-------------------------------------------------------------------------
-
     def rebuild_editor(self):
         """ Rebuilds the contents of the editor whenever the original factory
             object's **values** trait changes.
@@ -373,21 +323,12 @@ class SimpleEditor(BaseEditor):
 
         self.update_editor()
 
-#-------------------------------------------------------------------------
-#  'RadioEditor' class:
-#-------------------------------------------------------------------------
-
 
 class RadioEditor(BaseEditor):
     """ Enumeration editor, used for the "custom" style, that displays radio
         buttons.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -398,10 +339,6 @@ class RadioEditor(BaseEditor):
         self.control = TraitsUIPanel(parent, -1)
         self.rebuild_editor()
 
-    #-------------------------------------------------------------------------
-    #  Handles the user clicking one of the 'custom' radio buttons:
-    #-------------------------------------------------------------------------
-
     def update_object(self, event):
         """ Handles the user clicking one of the custom radio buttons.
         """
@@ -410,26 +347,17 @@ class RadioEditor(BaseEditor):
         except:
             pass
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
         value = self.value
         for button in self.control.GetChildren():
-            state = (button.value == value)
+            state = button.value == value
             button.SetValue(state)
             if state:
                 button.SetFocus()
 
-    #-------------------------------------------------------------------------
-    #  Rebuilds the contents of the editor whenever the original factory
-    #  object's 'values' trait changes:
-    #-------------------------------------------------------------------------
-
     def rebuild_editor(self):
         """ Rebuilds the contents of the editor whenever the original factory
             object's **values** trait changes.
@@ -447,11 +375,11 @@ class RadioEditor(BaseEditor):
         mapping = self.mapping
         n = len(names)
         cols = self.factory.cols
-        rows = (n + cols - 1) / cols
-        incr = [n / cols] * cols
+        rows = (n + cols - 1) // cols
+        incr = [n // cols] * cols
         rem = n % cols
         for i in range(cols):
-            incr[i] += (rem > i)
+            incr[i] += rem > i
         incr[-1] = -(reduce(lambda x, y: x + y, incr[:-1], 0) - 1)
         if cols > 1:
             sizer = wx.GridSizer(0, cols, 2, 4)
@@ -470,35 +398,25 @@ class RadioEditor(BaseEditor):
                     control.value = mapping[name]
                     style = 0
                     control.SetValue(name == cur_name)
-                    wx.EVT_RADIOBUTTON(panel, control.GetId(),
-                                       self.update_object)
+                    panel.Bind(wx.EVT_RADIOBUTTON, self.update_object, id= control.GetId())
                     self.set_tooltip(control)
                     index += incr[j]
                     n -= 1
                 else:
-                    control = wx.RadioButton(panel, -1, '')
-                    control.value = ''
+                    control = wx.RadioButton(panel, -1, "")
+                    control.value = ""
                     control.Show(False)
                 sizer.Add(control, 0, wx.NORTH, 5)
 
         # Set-up the layout:
         panel.SetSizerAndFit(sizer)
 
-#-------------------------------------------------------------------------
-#  'ListEditor' class:
-#-------------------------------------------------------------------------
-
 
 class ListEditor(BaseEditor):
     """ Enumeration editor, used for the "custom" style, that displays a list
         box.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -506,10 +424,15 @@ class ListEditor(BaseEditor):
         super(ListEditor, self).init(parent)
 
         # Create a panel to hold all of the radio buttons:
-        self.control = wx.ListBox(parent, -1, wx.Point(0, 0),
-                                  wx.Size(-1, -1), self.names,
-                                  style=wx.LB_SINGLE | wx.LB_NEEDED_SB)
-        wx.EVT_LISTBOX(parent, self.control.GetId(), self.update_object)
+        self.control = wx.ListBox(
+            parent,
+            -1,
+            wx.Point(0, 0),
+            wx.Size(-1, -1),
+            self.names,
+            style=wx.LB_SINGLE | wx.LB_NEEDED_SB,
+        )
+        parent.Bind(wx.EVT_LISTBOX, self.update_object, id=self.control.GetId())
         self.set_tooltip()
 
     def dispose(self):
@@ -519,10 +442,6 @@ class ListEditor(BaseEditor):
 
         super(ListEditor, self).dispose()
 
-    #-------------------------------------------------------------------------
-    #  Handles the user selecting a list box item:
-    #-------------------------------------------------------------------------
-
     def update_object(self, event):
         """ Handles the user selecting a list box item.
         """
@@ -540,10 +459,6 @@ class ListEditor(BaseEditor):
             except:
                 pass
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -556,11 +471,6 @@ class ListEditor(BaseEditor):
         except:
             pass
 
-    #-------------------------------------------------------------------------
-    #  Rebuilds the contents of the editor whenever the original factory
-    #  object's 'values' trait changes:
-    #-------------------------------------------------------------------------
-
     def rebuild_editor(self):
         """ Rebuilds the contents of the editor whenever the original factory
             object's **values** trait changes.
@@ -572,5 +482,3 @@ class ListEditor(BaseEditor):
 
         # fixme: Is this line necessary?
         self.update_editor()
-
-### EOF #######################################################################
