@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,16 +13,13 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the HTML "editor" for the wxPython user interface toolkit.
     HTML editors interpret and display HTML-formatted text, but do not
     modify it.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 import os.path
 import webbrowser
@@ -38,10 +35,6 @@ from traitsui.editors.html_editor import ToolkitEditorFactory
 
 from .editor import Editor
 
-#-------------------------------------------------------------------------
-#  URLResolvingHtmlWindow class:
-#-------------------------------------------------------------------------
-
 
 class URLResolvingHtmlWindow(wh.HtmlWindow):
     """ Overrides OnOpeningURL method of HtmlWindow to append the base URL
@@ -58,11 +51,10 @@ class URLResolvingHtmlWindow(wh.HtmlWindow):
         """
         if self.open_externally:
             url = link_info.GetHref()
-            if (self.base_url and
-                    not url.startswith(('http://', 'https://'))):
+            if self.base_url and not url.startswith(("http://", "https://")):
                 url = self.base_url + url
-            if not url.startswith(('file://', 'http://', 'https://')):
-                url = 'file://' + url
+            if not url.startswith(("file://", "http://", "https://")):
+                url = "file://" + url
             webbrowser.open_new(url)
 
     def OnOpeningURL(self, url_type, url):
@@ -71,50 +63,41 @@ class URLResolvingHtmlWindow(wh.HtmlWindow):
             for image loading, hence the base url handling code in
             OnLinkClicked.
         """
-        if (self.base_url and not os.path.isabs(url) and
-                not url.startswith(('http://', 'https://', self.base_url))):
-            return self.base_url + url
+        if (
+            self.base_url
+            and not os.path.isabs(url)
+            and not url.startswith(("http://", "https://", self.base_url))
+        ):
+            return wh.HTML_REDIRECT, self.base_url + url
         else:
-            return wh.HTML_OPEN
-
-#-------------------------------------------------------------------------
-#  'SimpleEditor' class:
-#-------------------------------------------------------------------------
+            return wh.HTML_OPEN, url
 
 
 class SimpleEditor(Editor):
     """ Simple style of editor for HTML, which displays interpreted HTML.
     """
-    #-------------------------------------------------------------------------
-    #  Trait definitions:
-    #-------------------------------------------------------------------------
 
-    # Is the HTML editor scrollable? This values override the default.
+    # -------------------------------------------------------------------------
+    #  Trait definitions:
+    # -------------------------------------------------------------------------
+
+    #: Is the HTML editor scrollable? This values override the default.
     scrollable = True
 
-    # External objects referenced in the HTML are relative to this URL
-    base_url = Str
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    #: External objects referenced in the HTML are relative to this URL
+    base_url = Str()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
-        self.control = URLResolvingHtmlWindow(parent,
-                                              self.factory.open_externally,
-                                              self.base_url)
+        self.control = URLResolvingHtmlWindow(
+            parent, self.factory.open_externally, self.base_url
+        )
         self.control.SetBorders(2)
 
         self.base_url = self.factory.base_url
-        self.sync_value(self.factory.base_url_name, 'base_url', 'from')
-
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
+        self.sync_value(self.factory.base_url_name, "base_url", "from")
 
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
@@ -125,13 +108,11 @@ class SimpleEditor(Editor):
             text = self.factory.parse_text(text)
         self.control.SetPage(text)
 
-    #-- Event Handlers -------------------------------------------------------
+    # -- Event Handlers -------------------------------------------------------
 
     def _base_url_changed(self):
         url = self.base_url
-        if not url.endswith('/'):
-            url += '/'
+        if not url.endswith("/"):
+            url += "/"
         self.control.base_url = url
         self.update_editor()
-
-#--EOF-------------------------------------------------------------------------
