@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2007, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,86 +13,71 @@
 #  Author: David C. Morrill
 #  Date:   07/14/2008
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Traits UI simple, scrubber-based integer or float value editor.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 import wx
 
-from math \
-    import log10, pow
+from math import log10, pow
 
-from traits.api \
-    import Any, BaseRange, BaseEnum, Str, Float, TraitError, \
-    on_trait_change
+from traits.api import (
+    Any,
+    BaseRange,
+    BaseEnum,
+    Str,
+    Float,
+    TraitError,
+    on_trait_change,
+)
 
-from traitsui.api \
-    import View, Item, EnumEditor
+from traitsui.api import View, Item, EnumEditor
 
 # FIXME: ScrubberEditor is a proxy class defined here just for backward
 # compatibility (represents the editor factory for scrubber editors).
 # The class has been moved to traitsui.editors.scrubber_editor
-from traitsui.editors.scrubber_editor \
-    import ScrubberEditor
+from traitsui.editors.scrubber_editor import ScrubberEditor
 
-from traitsui.wx.editor \
-    import Editor
+from traitsui.wx.editor import Editor
 
-from pyface.timer.api \
-    import do_after
+from pyface.timer.api import do_after
 
-from .constants \
-    import ErrorColor
+from .constants import ErrorColor
 
-from .image_slice \
-    import paint_parent
+from .image_slice import paint_parent
 
-from .helper \
-    import disconnect, disconnect_no_id, BufferDC
-
-#-------------------------------------------------------------------------
-#  '_ScrubberEditor' class:
-#-------------------------------------------------------------------------
+from .helper import disconnect, disconnect_no_id, BufferDC
 
 
 class _ScrubberEditor(Editor):
     """ Traits UI simple, scrubber-based integer or float value editor.
     """
 
-    # The low end of the slider range:
-    low = Any
+    #: The low end of the slider range:
+    low = Any()
 
-    # The high end of the slider range:
-    high = Any
+    #: The high end of the slider range:
+    high = Any()
 
-    # The smallest allowed increment:
-    increment = Float
+    #: The smallest allowed increment:
+    increment = Float()
 
-    # The current text being displayed:
-    text = Str
+    #: The current text being displayed:
+    text = Str()
 
-    # The mapping to use (only for Enum's):
-    mapping = Any
+    #: The mapping to use (only for Enum's):
+    mapping = Any()
 
-    #-- Class Variables ------------------------------------------------------
+    # -- Class Variables ------------------------------------------------------
 
     text_styles = {
-        'left': wx.TE_LEFT,
-        'center': wx.TE_CENTRE,
-        'right': wx.TE_RIGHT
+        "left": wx.TE_LEFT,
+        "center": wx.TE_CENTRE,
+        "right": wx.TE_RIGHT,
     }
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -100,7 +85,7 @@ class _ScrubberEditor(Editor):
         factory = self.factory
 
         # Establish the range of the slider:
-        low_name = high_name = ''
+        low_name = high_name = ""
         low, high = factory.low, factory.high
         if high <= low:
             low = high = None
@@ -108,58 +93,56 @@ class _ScrubberEditor(Editor):
             if isinstance(handler, BaseRange):
                 low_name, high_name = handler._low_name, handler._high_name
 
-                if low_name == '':
+                if low_name == "":
                     low = handler._low
 
-                if high_name == '':
+                if high_name == "":
                     high = handler._high
 
             elif isinstance(handler, BaseEnum):
-                if handler.name == '':
+                if handler.name == "":
                     self.mapping = handler.values
                 else:
-                    self.sync_value(handler.name, 'mapping', 'from')
+                    self.sync_value(handler.name, "mapping", "from")
 
                 low, high = 0, self.high
 
         # Create the control:
-        self.control = control = wx.Window(parent, -1,
-                                           size=wx.Size(50, 18),
-                                           style=wx.FULL_REPAINT_ON_RESIZE |
-                                           wx.TAB_TRAVERSAL)
+        self.control = control = wx.Window(
+            parent,
+            -1,
+            size=wx.Size(50, 18),
+            style=wx.FULL_REPAINT_ON_RESIZE | wx.TAB_TRAVERSAL,
+        )
 
         # Set up the painting event handlers:
-        wx.EVT_ERASE_BACKGROUND(control, self._erase_background)
-        wx.EVT_PAINT(control, self._on_paint)
-        wx.EVT_SET_FOCUS(control, self._set_focus)
+        control.Bind(wx.EVT_ERASE_BACKGROUND, self._erase_background)
+        control.Bind(wx.EVT_PAINT, self._on_paint)
+        control.Bind(wx.EVT_SET_FOCUS, self._set_focus)
 
         # Set up mouse event handlers:
-        wx.EVT_LEAVE_WINDOW(control, self._leave_window)
-        wx.EVT_ENTER_WINDOW(control, self._enter_window)
-        wx.EVT_LEFT_DOWN(control, self._left_down)
-        wx.EVT_LEFT_UP(control, self._left_up)
-        wx.EVT_MOTION(control, self._motion)
-        wx.EVT_MOUSEWHEEL(control, self._mouse_wheel)
+        control.Bind(wx.EVT_LEAVE_WINDOW, self._leave_window)
+        control.Bind(wx.EVT_ENTER_WINDOW, self._enter_window)
+        control.Bind(wx.EVT_LEFT_DOWN, self._left_down)
+        control.Bind(wx.EVT_LEFT_UP, self._left_up)
+        control.Bind(wx.EVT_MOTION, self._motion)
+        control.Bind(wx.EVT_MOUSEWHEEL, self._mouse_wheel)
 
         # Set up the control resize handler:
-        wx.EVT_SIZE(control, self._resize)
+        control.Bind(wx.EVT_SIZE, self._resize)
 
         # Set the tooltip:
-        self._can_set_tooltip = (not self.set_tooltip())
+        self._can_set_tooltip = not self.set_tooltip()
 
         # Save the values we calculated:
         self.trait_set(low=low, high=high)
-        self.sync_value(low_name, 'low', 'from')
-        self.sync_value(high_name, 'high', 'from')
+        self.sync_value(low_name, "low", "from")
+        self.sync_value(high_name, "high", "from")
 
         # Force a reset (in case low = high = None, which won't cause a
         # notification to fire):
         self._reset_scrubber()
 
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
-
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
@@ -175,17 +158,14 @@ class _ScrubberEditor(Editor):
             wx.EVT_LEFT_UP,
             wx.EVT_MOTION,
             wx.EVT_MOUSEWHEEL,
-            wx.EVT_SIZE)
+            wx.EVT_SIZE,
+        )
 
         # Disconnect the pop-up text event handlers:
         self._disconnect_text()
 
         super(_ScrubberEditor, self).dispose()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -196,10 +176,6 @@ class _ScrubberEditor(Editor):
 
         self._enum_completed()
 
-    #-------------------------------------------------------------------------
-    #  Updates the object when the scrubber value changes:
-    #-------------------------------------------------------------------------
-
     def update_object(self, value):
         """ Updates the object when the scrubber value changes.
         """
@@ -216,44 +192,40 @@ class _ScrubberEditor(Editor):
                     self.value = value
                     self.update_editor()
 
-    #-------------------------------------------------------------------------
-    #  Handles an error that occurs while setting the object's trait value:
-    #-------------------------------------------------------------------------
-
     def error(self, excp):
         """ Handles an error that occurs while setting the object's trait value.
         """
         pass
 
-    #-- Trait Event Handlers -------------------------------------------------
+    # -- Trait Event Handlers -------------------------------------------------
 
     def _mapping_changed(self, mapping):
         """ Handles the Enum mapping being changed.
         """
         self.high = len(mapping) - 1
 
-    #-- Private Methods ------------------------------------------------------
+    # -- Private Methods ------------------------------------------------------
 
-    @on_trait_change('low, high')
+    @on_trait_change("low, high")
     def _reset_scrubber(self):
         """ Sets the the current tooltip.
         """
         low, high = self.low, self.high
         if self._can_set_tooltip:
             if self.mapping is not None:
-                tooltip = '[%s]' % (', '.join(self.mapping))
+                tooltip = "[%s]" % (", ".join(self.mapping))
                 if len(tooltip) > 80:
-                    tooltip = ''
+                    tooltip = ""
             elif high is None:
-                tooltip = ''
+                tooltip = ""
                 if low is not None:
-                    tooltip = '[%g..]' % low
+                    tooltip = "[%g..]" % low
             elif low is None:
-                tooltip = '[..%g]' % high
+                tooltip = "[..%g]" % high
             else:
-                tooltip = '[%g..%g]' % (low, high)
+                tooltip = "[%g..%g]" % (low, high)
 
-            self.control.SetToolTipString(tooltip)
+            self.control.SetToolTip(tooltip)
 
         # Establish the slider increment:
         increment = self.factory.increment
@@ -272,13 +244,13 @@ class _ScrubberEditor(Editor):
             displayed.
         """
         tdx, tdy, descent, leading = self._get_text_size()
-        wdx, wdy = self.control.GetClientSizeTuple()
-        ty = ((wdy - (tdy - descent)) / 2) - 1
+        wdx, wdy = self.control.GetClientSize()
+        ty = ((wdy - (tdy - descent)) // 2) - 1
         alignment = self.factory.alignment
-        if alignment == 'left':
+        if alignment == "left":
             tx = 0
-        elif alignment == 'center':
-            tx = (wdx - tdx) / 2
+        elif alignment == "center":
+            tx = (wdx - tdx) // 2
         else:
             tx = wdx - tdx
 
@@ -289,7 +261,8 @@ class _ScrubberEditor(Editor):
         """
         if self._text_size is None:
             self._text_size = self.control.GetFullTextExtent(
-                self.text.strip() or 'M')
+                self.text.strip() or "M"
+            )
 
         return self._text_size
 
@@ -330,7 +303,7 @@ class _ScrubberEditor(Editor):
         """ Pop-up a text control to allow the user to enter a value using
             the keyboard.
         """
-        self.control.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
+        self.control.SetCursor(wx.Cursor(wx.CURSOR_ARROW))
 
         if self.mapping is not None:
             self._pop_up_enum()
@@ -340,34 +313,42 @@ class _ScrubberEditor(Editor):
     def _pop_up_enum(self):
         self._ui = self.object.edit_traits(
             view=View(
-                Item(self.name,
-                     id='drop_down',
-                     show_label=False,
-                     padding=-4,
-                     editor=EnumEditor(name='editor.mapping')),
-                kind='subpanel'),
+                Item(
+                    self.name,
+                    id="drop_down",
+                    show_label=False,
+                    padding=-4,
+                    editor=EnumEditor(name="editor.mapping"),
+                ),
+                kind="subpanel",
+            ),
             parent=self.control,
-            context={'object': self.object, 'editor': self})
+            context={"object": self.object, "editor": self},
+        )
 
-        dx, dy = self.control.GetSizeTuple()
+        dx, dy = self.control.GetSize()
         drop_down = self._ui.info.drop_down.control
-        drop_down.SetDimensions(0, 0, dx, dy)
+        drop_down.SetSize(0, 0, dx, dy)
         drop_down.SetFocus()
-        wx.EVT_KILL_FOCUS(drop_down, self._enum_completed)
+        drop_down.Bind(wx.EVT_KILL_FOCUS, self._enum_completed)
 
     def _pop_up_text(self):
         control = self.control
-        self._text = text = wx.TextCtrl(control, -1, str(self.value),
-                                        size=control.GetSize(),
-                                        style=self.text_styles[self.factory.alignment] |
-                                        wx.TE_PROCESS_ENTER)
+        self._text = text = wx.TextCtrl(
+            control,
+            -1,
+            str(self.value),
+            size=control.GetSize(),
+            style=self.text_styles[self.factory.alignment]
+            | wx.TE_PROCESS_ENTER,
+        )
         text.SetSelection(-1, -1)
         text.SetFocus()
-        wx.EVT_TEXT_ENTER(control, text.GetId(), self._text_completed)
-        wx.EVT_KILL_FOCUS(text, self._text_completed)
-        wx.EVT_ENTER_WINDOW(text, self._enter_text)
-        wx.EVT_LEAVE_WINDOW(text, self._leave_text)
-        wx.EVT_CHAR(text, self._key_entered)
+        control.Bind(wx.EVT_TEXT_ENTER, self._text_completed, id=text.GetId())
+        text.Bind(wx.EVT_KILL_FOCUS, self._text_completed)
+        text.Bind(wx.EVT_ENTER_WINDOW, self._enter_text)
+        text.Bind(wx.EVT_LEAVE_WINDOW, self._leave_text)
+        text.Bind(wx.EVT_CHAR, self._key_entered)
 
     def _destroy_text(self):
         """ Destroys the current text control.
@@ -390,7 +371,8 @@ class _ScrubberEditor(Editor):
                 wx.EVT_KILL_FOCUS,
                 wx.EVT_ENTER_WINDOW,
                 wx.EVT_LEAVE_WINDOW,
-                wx.EVT_CHAR)
+                wx.EVT_CHAR,
+            )
 
     def _init_value(self):
         """ Initializes the current value when the user begins a drag or moves
@@ -404,7 +386,7 @@ class _ScrubberEditor(Editor):
         else:
             self._value = self.value
 
-    #--- wxPython Event Handlers ---------------------------------------------
+    # --- wxPython Event Handlers ---------------------------------------------
 
     def _erase_background(self, event):
         """ Do not erase the background here (do it in the 'on_paint' handler).
@@ -440,7 +422,7 @@ class _ScrubberEditor(Editor):
             pen = wx.TRANSPARENT_PEN
 
         if (pen != wx.TRANSPARENT_PEN) or (brush != wx.TRANSPARENT_BRUSH):
-            wdx, wdy = control.GetClientSizeTuple()
+            wdx, wdy = control.GetClientSize()
             dc.SetBrush(brush)
             dc.SetPen(pen)
             dc.DrawRectangle(0, 0, wdx, wdy)
@@ -464,9 +446,11 @@ class _ScrubberEditor(Editor):
     def _set_focus(self, event):
         """ Handle the control getting the keyboard focus.
         """
-        if ((not self._ignore_focus) and
-            (self._x is None) and
-                (self._text is None)):
+        if (
+            (not self._ignore_focus)
+            and (self._x is None)
+            and (self._text is None)
+        ):
             self._pop_up_editor()
 
         event.Skip()
@@ -476,7 +460,7 @@ class _ScrubberEditor(Editor):
         """
         self._hover = True
 
-        self.control.SetCursor(wx.StockCursor(wx.CURSOR_HAND))
+        self.control.SetCursor(wx.Cursor(wx.CURSOR_HAND))
 
         if not self._ignore_focus:
             self._ignore_focus = True
@@ -554,7 +538,7 @@ class _ScrubberEditor(Editor):
             clicks = 3
             if event.ShiftDown():
                 clicks = 7
-            delta = clicks * (event.GetWheelRotation() / event.GetWheelDelta())
+            delta = clicks * (event.GetWheelRotation() // event.GetWheelDelta())
             self._set_scrubber_position(event, delta)
 
     def _update_value(self, event):
@@ -595,8 +579,9 @@ class _ScrubberEditor(Editor):
         """
         if self._ui is not None:
             self._ignore_focus = True
-            disconnect_no_id(self._ui.info.drop_down.control,
-                             wx.EVT_KILL_FOCUS)
+            disconnect_no_id(
+                self._ui.info.drop_down.control, wx.EVT_KILL_FOCUS
+            )
             self._ui.dispose()
             del self._ui
 
