@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
-#  Copyright (c) 2005, Enthought, Inc.
+#  Copyright (c) 2005-19, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,70 +13,65 @@
 #  Author: David C. Morrill
 #  Date:   10/13/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the concrete implementations of the traits Toolkit interface for
     the wxPython user interface toolkit.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 # Make sure that importimg from this backend is OK:
-from __future__ import absolute_import
+import logging
+
 from traitsui.toolkit import assert_toolkit_import
-assert_toolkit_import(['wx'])
+
+assert_toolkit_import(["wx"])
 
 import wx
 
 # Ensure that we can import Pyface backend.  This starts App as a side-effect.
 from pyface.toolkit import toolkit_object as pyface_toolkit
-_app = pyface_toolkit('init:_app')
 
-from traits.api import (
-    HasPrivateTraits, Instance, Property, Category, cached_property
-)
+_app = pyface_toolkit("init:_app")
+
+from traits.api import HasPrivateTraits, Instance
 from traits.trait_notifiers import set_ui_handler
 from pyface.wx.drag_and_drop import PythonDropTarget
 
 from traitsui.theme import Theme
 from traitsui.ui import UI
-from traitsui.dock_window_theme import DockWindowTheme
 from traitsui.toolkit import Toolkit
-
 from .constants import WindowColor, screen_dx, screen_dy
 from .helper import position_window
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
+logger = logging.getLogger(__name__)
+
+
+#: Mapping from wx events to method suffixes.
 EventSuffix = {
-    wx.wxEVT_LEFT_DOWN: 'left_down',
-    wx.wxEVT_LEFT_DCLICK: 'left_dclick',
-    wx.wxEVT_LEFT_UP: 'left_up',
-    wx.wxEVT_MIDDLE_DOWN: 'middle_down',
-    wx.wxEVT_MIDDLE_DCLICK: 'middle_dclick',
-    wx.wxEVT_MIDDLE_UP: 'middle_up',
-    wx.wxEVT_RIGHT_DOWN: 'right_down',
-    wx.wxEVT_RIGHT_DCLICK: 'right_dclick',
-    wx.wxEVT_RIGHT_UP: 'right_up',
-    wx.wxEVT_MOTION: 'mouse_move',
-    wx.wxEVT_ENTER_WINDOW: 'enter',
-    wx.wxEVT_LEAVE_WINDOW: 'leave',
-    wx.wxEVT_MOUSEWHEEL: 'mouse_wheel',
-    wx.wxEVT_PAINT: 'paint',
+    wx.wxEVT_LEFT_DOWN: "left_down",
+    wx.wxEVT_LEFT_DCLICK: "left_dclick",
+    wx.wxEVT_LEFT_UP: "left_up",
+    wx.wxEVT_MIDDLE_DOWN: "middle_down",
+    wx.wxEVT_MIDDLE_DCLICK: "middle_dclick",
+    wx.wxEVT_MIDDLE_UP: "middle_up",
+    wx.wxEVT_RIGHT_DOWN: "right_down",
+    wx.wxEVT_RIGHT_DCLICK: "right_dclick",
+    wx.wxEVT_RIGHT_UP: "right_up",
+    wx.wxEVT_MOTION: "mouse_move",
+    wx.wxEVT_ENTER_WINDOW: "enter",
+    wx.wxEVT_LEAVE_WINDOW: "leave",
+    wx.wxEVT_MOUSEWHEEL: "mouse_wheel",
+    wx.wxEVT_PAINT: "paint",
 }
 
-# Types of popup views:
-Popups = {'popup', 'popover', 'info'}
+#: Types of popup views:
+Popups = {"popup", "popover", "info"}
 
-#-------------------------------------------------------------------------
-#  Handles UI notification handler requests that occur on a thread other than
-#  the UI thread:
-#-------------------------------------------------------------------------
 
+# -------------------------------------------------------------------------
+# Traits UI dispatch infrastructure
+# -------------------------------------------------------------------------
 
 def ui_handler(handler, *args):
     """ Handles UI notification handler requests that occur on a thread other
@@ -84,27 +79,25 @@ def ui_handler(handler, *args):
     """
     wx.CallAfter(handler, *args)
 
+
 # Tell the traits notification handlers to use this UI handler
 set_ui_handler(ui_handler)
 
-#-------------------------------------------------------------------------
-#  'GUIToolkit' class:
-#-------------------------------------------------------------------------
 
+# -------------------------------------------------------------------------
+# Wx Toolkit Implementation
+# -------------------------------------------------------------------------
 
 class GUIToolkit(Toolkit):
     """ Implementation class for wxPython toolkit.
     """
-    #-------------------------------------------------------------------------
-    #  Create wxPython specific user interfaces using information from the
-    #  specified UI object:
-    #-------------------------------------------------------------------------
 
     def ui_panel(self, ui, parent):
         """ Creates a wxPython panel-based user interface using information
             from the specified UI object.
         """
         from . import ui_panel
+
         ui_panel.ui_panel(ui, parent)
 
     def ui_subpanel(self, ui, parent):
@@ -112,6 +105,7 @@ class GUIToolkit(Toolkit):
             from the specified UI object.
         """
         from . import ui_panel
+
         ui_panel.ui_subpanel(ui, parent)
 
     def ui_livemodal(self, ui, parent):
@@ -119,6 +113,7 @@ class GUIToolkit(Toolkit):
             information from the specified UI object.
         """
         from . import ui_live
+
         ui_live.ui_livemodal(ui, parent)
 
     def ui_live(self, ui, parent):
@@ -126,6 +121,7 @@ class GUIToolkit(Toolkit):
             using information from the specified UI object.
         """
         from . import ui_live
+
         ui_live.ui_live(ui, parent)
 
     def ui_modal(self, ui, parent):
@@ -133,6 +129,7 @@ class GUIToolkit(Toolkit):
             from the specified UI object.
         """
         from . import ui_modal
+
         ui_modal.ui_modal(ui, parent)
 
     def ui_nonmodal(self, ui, parent):
@@ -140,6 +137,7 @@ class GUIToolkit(Toolkit):
             information from the specified UI object.
         """
         from . import ui_modal
+
         ui_modal.ui_nonmodal(ui, parent)
 
     def ui_popup(self, ui, parent):
@@ -147,6 +145,7 @@ class GUIToolkit(Toolkit):
             interface using information from the specified UI object.
         """
         from . import ui_live
+
         ui_live.ui_popup(ui, parent)
 
     def ui_popover(self, ui, parent):
@@ -154,6 +153,7 @@ class GUIToolkit(Toolkit):
             interface using information from the specified UI object.
         """
         from . import ui_live
+
         ui_live.ui_popover(ui, parent)
 
     def ui_info(self, ui, parent):
@@ -161,6 +161,7 @@ class GUIToolkit(Toolkit):
             interface using information from the specified UI object.
         """
         from . import ui_live
+
         ui_live.ui_info(ui, parent)
 
     def ui_wizard(self, ui, parent):
@@ -168,10 +169,19 @@ class GUIToolkit(Toolkit):
             from the specified UI object.
         """
         from . import ui_wizard
+
         ui_wizard.ui_wizard(ui, parent)
 
-    def view_application(self, context, view, kind=None, handler=None,
-                         id='', scrollable=None, args=None):
+    def view_application(
+        self,
+        context,
+        view,
+        kind=None,
+        handler=None,
+        id="",
+        scrollable=None,
+        args=None,
+    ):
         """ Creates a wxPython modal dialog user interface that
             runs as a complete application, using information from the
             specified View object.
@@ -204,12 +214,10 @@ class GUIToolkit(Toolkit):
 
         """
         from . import view_application
-        return view_application.view_application(context, view, kind, handler,
-                                                 id, scrollable, args)
 
-    #-------------------------------------------------------------------------
-    #  Positions the associated dialog window on the display:
-    #-------------------------------------------------------------------------
+        return view_application.view_application(
+            context, view, kind, handler, id, scrollable, args
+        )
 
     def position(self, ui):
         """ Positions the associated dialog window on the display.
@@ -223,11 +231,11 @@ class GUIToolkit(Toolkit):
             px, py = 0, 0
             pdx, pdy = screen_dx, screen_dy
         else:
-            px, py = parent.GetPositionTuple()
-            pdx, pdy = parent.GetSizeTuple()
+            px, py = parent.GetPosition()
+            pdx, pdy = parent.GetSize()
 
         # Calculate the correct width and height for the window:
-        cur_width, cur_height = window.GetSizeTuple()
+        cur_width, cur_height = window.GetSize()
         width = view.width
         height = view.height
 
@@ -257,7 +265,7 @@ class GUIToolkit(Toolkit):
             # BH- I think this is the case when there is a parent
             # so this logic tries to place it in the middle of the parent
             # if possible, otherwise tries an offset from the parent
-            x = px + (pdx - width) / 2
+            x = px + (pdx - width) // 2
             if x < 0:
                 x = px + 20
         elif x <= -1.0:
@@ -273,7 +281,7 @@ class GUIToolkit(Toolkit):
             # BH- I think this is the case when there is a parent
             # so this logic tries to place it in the middle of the parent
             # if possible, otherwise tries an offset from the parent
-            y = py + (pdy - height) / 2
+            y = py + (pdy - height) // 2
             if y < 0:
                 y = py + 20
         elif y <= -1.0:
@@ -291,21 +299,14 @@ class GUIToolkit(Toolkit):
         y = min(y, wx.DisplaySize()[1])
 
         # Position and size the window as requested:
-        window.SetDimensions(max(0, x), max(0, y), width, height)
-
-    #-------------------------------------------------------------------------
-    #  Shows a 'Help' window for a specified UI and control:
-    #-------------------------------------------------------------------------
+        window.SetSize(max(0, x), max(0, y), width, height)
 
     def show_help(self, ui, control):
         """ Shows a help window for a specified UI and control.
         """
         from . import ui_panel
-        ui_panel.show_help(ui, control)
 
-    #-------------------------------------------------------------------------
-    #  Saves user preference information associated with a UI window:
-    #-------------------------------------------------------------------------
+        ui_panel.show_help(ui, control)
 
     def save_window(self, ui):
         """ Saves user preference information associated with a UI window.
@@ -314,10 +315,6 @@ class GUIToolkit(Toolkit):
 
         helper.save_window(ui)
 
-    #-------------------------------------------------------------------------
-    #  Rebuilds a UI after a change to the content of the UI:
-    #-------------------------------------------------------------------------
-
     def rebuild_ui(self, ui):
         """ Rebuilds a UI after a change to the content of the UI.
         """
@@ -339,19 +336,11 @@ class GUIToolkit(Toolkit):
             if sizer is not None:
                 sizer.Add(ui.control, 1, wx.EXPAND)
 
-    #-------------------------------------------------------------------------
-    #  Sets the title for the UI window:
-    #-------------------------------------------------------------------------
-
     def set_title(self, ui):
         """ Sets the title for the UI window.
         """
         ui.control.SetTitle(ui.title)
 
-    #-------------------------------------------------------------------------
-    #  Sets the icon for the UI window:
-    #-------------------------------------------------------------------------
-
     def set_icon(self, ui):
         """ Sets the icon for the UI window.
         """
@@ -360,10 +349,6 @@ class GUIToolkit(Toolkit):
         if isinstance(ui.icon, ImageResource):
             ui.control.SetIcon(ui.icon.create_icon())
 
-    #-------------------------------------------------------------------------
-    #  Converts a keystroke event into a corresponding key name:
-    #-------------------------------------------------------------------------
-
     def key_event_to_name(self, event):
         """ Converts a keystroke event into a corresponding key name.
         """
@@ -371,11 +356,6 @@ class GUIToolkit(Toolkit):
 
         return key_event_to_name.key_event_to_name(event)
 
-    #-------------------------------------------------------------------------
-    #  Hooks all specified events for all controls in a ui so that they can be
-    #  routed to the correct event handler:
-    #-------------------------------------------------------------------------
-
     def hook_events(self, ui, control, events=None, handler=None):
         """ Hooks all specified events for all controls in a UI so that they
             can be routed to the correct event handler.
@@ -395,11 +375,13 @@ class GUIToolkit(Toolkit):
                 wx.wxEVT_ENTER_WINDOW,
                 wx.wxEVT_LEAVE_WINDOW,
                 wx.wxEVT_MOUSEWHEEL,
-                wx.wxEVT_PAINT)
-            control.SetDropTarget(PythonDropTarget(
-                DragHandler(ui=ui, control=control)))
-        elif events == 'keys':
-            events = (wx.wxEVT_CHAR, )
+                wx.wxEVT_PAINT,
+            )
+            control.SetDropTarget(
+                PythonDropTarget(DragHandler(ui=ui, control=control))
+            )
+        elif events == "keys":
+            events = (wx.wxEVT_CHAR,)
 
         if handler is None:
             handler = ui.route_event
@@ -416,10 +398,6 @@ class GUIToolkit(Toolkit):
         for child in control.GetChildren():
             self.hook_events(ui, child, events, handler)
 
-    #-------------------------------------------------------------------------
-    #  Routes a 'hooked' event to the correct handler method:
-    #-------------------------------------------------------------------------
-
     def route_event(self, ui, event):
         """ Routes a hooked event to the correct handler method.
         """
@@ -428,41 +406,34 @@ class GUIToolkit(Toolkit):
         handler = ui.handler
         method = None
 
-        owner = getattr(control, '_owner', None)
+        owner = getattr(control, "_owner", None)
         if owner is not None:
-            method = getattr(handler, 'on_%s_%s' % (owner.get_id(), suffix),
-                             None)
+            method = getattr(
+                handler, "on_%s_%s" % (owner.get_id(), suffix), None
+            )
 
         if method is None:
-            method = (getattr(handler, 'on_%s' % suffix, None) or
-                      getattr(handler, 'on_any_event', None))
+            method = getattr(handler, "on_%s" % suffix, None) or getattr(
+                handler, "on_any_event", None
+            )
 
         if (method is None) or (method(ui.info, owner, event) is False):
             event.Skip()
 
-    #-------------------------------------------------------------------------
-    #  Indicates that an event should continue to be processed by the toolkit
-    #-------------------------------------------------------------------------
-
     def skip_event(self, event):
         """ Indicates that an event should continue to be processed by the
             toolkit.
         """
         event.Skip()
 
-    #-------------------------------------------------------------------------
-    #  Destroys a specified GUI toolkit control:
-    #-------------------------------------------------------------------------
-
     def destroy_control(self, control):
         """ Destroys a specified GUI toolkit control.
         """
         _popEventHandlers(control)
-        control.Destroy()
-
-    #-------------------------------------------------------------------------
-    #  Destroys all of the child controls of a specified GUI toolkit control:
-    #-------------------------------------------------------------------------
+        try:
+            control.Destroy()
+        except Exception:
+            logger.exception("Wx control %r not destroyed cleanly", control)
 
     def destroy_children(self, control):
         """ Destroys all of the child controls of a specified GUI toolkit
@@ -472,21 +443,12 @@ class GUIToolkit(Toolkit):
             _popEventHandlers(child)
         control.DestroyChildren()
 
-    #-------------------------------------------------------------------------
-    #  Returns a ( width, height ) tuple containing the size of a specified
-    #  toolkit image:
-    #-------------------------------------------------------------------------
-
     def image_size(self, image):
         """ Returns a ( width, height ) tuple containing the size of a
             specified toolkit image.
         """
         return (image.GetWidth(), image.GetHeight())
 
-    #-------------------------------------------------------------------------
-    #  Returns a dictionary of useful constants:
-    #-------------------------------------------------------------------------
-
     def constants(self):
         """ Returns a dictionary of useful constants.
 
@@ -495,172 +457,89 @@ class GUIToolkit(Toolkit):
             - WindowColor': the standard window background color in the toolkit
               specific color format.
         """
-        return {
-            'WindowColor': WindowColor
-        }
+        return {"WindowColor": WindowColor}
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  GUI toolkit dependent trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def color_trait(self, *args, **traits):
         from . import color_trait as ct
+
         return ct.WxColor(*args, **traits)
 
     def rgb_color_trait(self, *args, **traits):
         from . import rgb_color_trait as rgbct
+
         return rgbct.RGBColor(*args, **traits)
 
     def font_trait(self, *args, **traits):
         from . import font_trait as ft
+
         return ft.WxFont(*args, **traits)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  'Editor' class methods:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Generic UI-base editor:
     def ui_editor(self):
+        """ Generic base UI editor. """
         from . import ui_editor
+
         return ui_editor.UIEditor
-#
-#    # Drag and drop:
-#    def dnd_editor ( self, *args, **traits ):
-#        import dnd_editor as dnd
-#        return dnd.ToolkitEditorFactory( *args, **traits)
-#
-#    # Key Binding:
-#    def key_binding_editor ( self, *args, **traits ):
-#        import key_binding_editor as kbe
-#        return kbe.ToolkitEditorFactory( *args, **traits )
-#
-#    # History:
-#    def history_editor ( self, *args, **traits ):
-#        import history_editor as he
-#        return he.HistoryEditor( *args, **traits )
-#
-#    # HTML:
-#    def html_editor ( self, *args, **traits ):
-#        import html_editor as he
-#        return he.ToolkitEditorFactory( *args, **traits )
-#
-#    # Image:
-#    def image_editor ( self, *args, **traits ):
-#        import image_editor as ie
-#        return ie.ImageEditor( *args, **traits )
-#
-#    # ListStr:
-#    def list_str_editor ( self, *args, **traits ):
-#        import list_str_editor as lse
-#        return lse.ListStrEditor( *args, **traits )
-#
-#    # Ordered set:
-#    def ordered_set_editor ( self, *args, **traits ):
-#        import ordered_set_editor as ose
-#        return ose.ToolkitEditorFactory( *args, **traits )
-#
-#    # Plot:
-#    def plot_editor ( self, *args, **traits ):
-#        import plot_editor as pe
-#        return pe.ToolkitEditorFactory( *args, **traits )
-#
-#    # Popup:
-#    def popup_editor ( self, *args, **traits ):
-#        import popup_editor as pe
-#        return pe.PopupEditor( *args, **traits )
-#
-#    # RGB Color:
-#    def rgb_color_editor ( self, *args, **traits ):
-#        import rgb_color_editor as rgbce
-#        return rgbce.ToolkitEditorFactory( *args, **traits )
-#
-#    # Scrubber:
-#    def scrubber_editor ( self, *args, **traits ):
-#        import scrubber_editor as se
-#        return se.ScrubberEditor( *args, **traits )
-#
-#    # Shell:
 
     def shell_editor(self, *args, **traits):
         from . import shell_editor as se
-        return se.ToolkitEditorFactory(*args, **traits)
-#
-#    # Tabular:
-#    def tabular_editor ( self, *args, **traits ):
-#        import tabular_editor as te
-#        return te.TabularEditor( *args, **traits )
-#
-#    # Value:
-#    def value_editor ( self, *args, **traits ):
-#        import value_editor as ve
-#        return ve.ToolkitEditorFactory( *args, **traits )
 
-#-------------------------------------------------------------------------
-#  'DragHandler' class:
-#-------------------------------------------------------------------------
+        return se.ToolkitEditorFactory(*args, **traits)
 
 
 class DragHandler(HasPrivateTraits):
     """ Handler for drag events.
     """
-    #-------------------------------------------------------------------------
-    #  Traits definitions:
-    #-------------------------------------------------------------------------
 
-    # The UI associated with the drag handler
+    # -------------------------------------------------------------------------
+    #  Traits definitions:
+    # -------------------------------------------------------------------------
+
+    #: The UI associated with the drag handler
     ui = Instance(UI)
 
-    # The wx control associated with the drag handler
+    #: The wx control associated with the drag handler
     control = Instance(wx.Window)
 
-#-- Drag and drop event handlers: ----------------------------------------
-
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dropped on the control:
-    #-------------------------------------------------------------------------
+    # -- Drag and drop event handlers: ----------------------------------------
 
     def wx_dropped_on(self, x, y, data, drag_result):
         """ Handles a Python object being dropped on the window.
         """
-        return self._drag_event('dropped_on', x, y, data, drag_result)
-
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dragged over the control:
-    #-------------------------------------------------------------------------
+        return self._drag_event("dropped_on", x, y, data, drag_result)
 
     def wx_drag_over(self, x, y, data, drag_result):
         """ Handles a Python object being dragged over the tree.
         """
-        return self._drag_event('drag_over', x, y, data, drag_result)
-
-    #-------------------------------------------------------------------------
-    #  Handles a dragged Python object leaving the window:
-    #-------------------------------------------------------------------------
+        return self._drag_event("drag_over", x, y, data, drag_result)
 
     def wx_drag_leave(self, data):
         """ Handles a dragged Python object leaving the window.
         """
-        return self._drag_event('drag_leave')
+        return self._drag_event("drag_leave")
 
-    #-------------------------------------------------------------------------
-    #  Handles routing a drag event to the appropriate handler:
-    #-------------------------------------------------------------------------
-
-    def _drag_event(self, suffix, x=None, y=None, data=None,
-                    drag_result=None):
+    def _drag_event(self, suffix, x=None, y=None, data=None, drag_result=None):
         """ Handles routing a drag event to the appropriate handler.
         """
         control = self.control
         handler = self.ui.handler
         method = None
 
-        owner = getattr(control, '_owner', None)
+        owner = getattr(control, "_owner", None)
         if owner is not None:
-            method = getattr(handler, 'on_%s_%s' % (owner.get_id(), suffix),
-                             None)
+            method = getattr(
+                handler, "on_%s_%s" % (owner.get_id(), suffix), None
+            )
 
         if method is None:
-            method = getattr(handler, 'on_%s' % suffix, None)
+            method = getattr(handler, "on_%s" % suffix, None)
 
         if method is None:
             return wx.DragNone
@@ -674,102 +553,6 @@ class DragHandler(HasPrivateTraits):
         return result
 
 
-#-------------------------------------------------------------------------
-#  Defines the extensions needed to make the generic Theme class specific to
-#  wxPython:
-#-------------------------------------------------------------------------
-
-
-class WXTheme(Category, Theme):
-    """ Defines the extensions needed to make the generic Theme class specific
-        to wxPython.
-    """
-
-    # The color to use for content text:
-    content_color = Property
-
-    # The color to use for label text:
-    label_color = Property
-
-    # The image slice used to draw the theme:
-    image_slice = Property(depends_on='image')
-
-    #-- Property Implementations ---------------------------------------------
-
-    def _get_content_color(self):
-        if self._content_color is None:
-            color = wx.BLACK
-            islice = self.image_slice
-            if islice is not None:
-                color = islice.content_color
-
-            self._content_color = color
-
-        return self._content_color
-
-    def _set_content_color(self, color):
-        self._content_color = color
-
-    def _get_label_color(self):
-        if self._label_color is None:
-            color = wx.BLACK
-            islice = self.image_slice
-            if islice is not None:
-                color = islice.label_color
-
-            self._label_color = color
-
-        return self._label_color
-
-    def _set_label_color(self, color):
-        self._label_color = color
-
-    @cached_property
-    def _get_image_slice(self):
-        from .image_slice import image_slice_for
-
-        if self.image is None:
-            return None
-
-        return image_slice_for(self.image)
-#-------------------------------------------------------------------------
-#  Defines the extensions needed to make the generic DockWindowTheme class
-#  specific to wxPython:
-#-------------------------------------------------------------------------
-
-
-class WXDockWindowTheme(Category, DockWindowTheme):
-    """ Defines the extensions needed to make the generic DockWindowTheme class
-        specific to wxPython.
-    """
-
-    # The bitmap for the 'tab_inactive_edge' image:
-    tab_inactive_edge_bitmap = Property(depends_on='tab_inactive_edge')
-
-    # The bitmap for the 'tab_hover_edge' image:
-    tab_hover_edge_bitmap = Property(depends_on='tab_hover_edge')
-
-    #-- Property Implementations ---------------------------------------------
-
-    @cached_property
-    def _get_tab_inactive_edge_bitmap(self):
-        image = self.tab_inactive_edge
-        if image is None:
-            return None
-
-        return image.create_image().ConvertToBitmap()
-
-    @cached_property
-    def _get_tab_hover_edge_bitmap(self):
-        image = self.tab_hover_edge
-        if image is None:
-            return self.tab_inactive_edge_bitmap
-
-        return image.create_image().ConvertToBitmap()
-
-
-#-------------------------------------------------------------------------
-
 class EventHandlerWrapper(wx.EvtHandler):
     """ Simple wrapper around wx.EvtHandler used to determine which event
     handlers were added by traitui.
@@ -777,17 +560,19 @@ class EventHandlerWrapper(wx.EvtHandler):
     pass
 
 
-def _popEventHandlers(ctrl):
+def _popEventHandlers(ctrl, handler_type=EventHandlerWrapper):
     """ Pop any event handlers that have been pushed on to a window and its
         children.
     """
+    # FIXME: have to special case URLResolvingHtmlWindow because it doesn't
+    # want its EvtHandler cleaned up.  See issue #752.
+    from .html_editor import URLResolvingHtmlWindow
 
-    # Assume that all traitsui event handlers are on the top of the stack
-    while ctrl is not ctrl.GetEventHandler():
-        handler = ctrl.GetEventHandler()
-        if isinstance(handler, EventHandlerWrapper):
+    handler = ctrl.GetEventHandler()
+    while ctrl is not handler:
+        next_handler = handler.GetNextHandler()
+        if isinstance(handler, handler_type):
             ctrl.PopEventHandler(True)
-        else:
-            break
+        handler = next_handler
     for child in ctrl.GetChildren():
-        _popEventHandlers(child)
+        _popEventHandlers(child, handler_type)
